var group___effects =
[
    [ "Ogre::Billboard", "class_ogre_1_1_billboard.html", [
      [ "Billboard", "class_ogre_1_1_billboard.html#a39ef001d2052cbae98014753e210b732", null ],
      [ "~Billboard", "class_ogre_1_1_billboard.html#a3ef9bffd0c2a51d1bbac274bdf86c869", null ],
      [ "Billboard", "class_ogre_1_1_billboard.html#aff96bdb3a3446cdf08499e58aa03c3c5", null ],
      [ "getRotation", "class_ogre_1_1_billboard.html#a7cb91052db2dd96a2c5c09d404f749a8", null ],
      [ "setRotation", "class_ogre_1_1_billboard.html#a8e64eda09ec65dea10dc180b68801d94", null ],
      [ "setPosition", "class_ogre_1_1_billboard.html#aeb9ce5d9c11492faf34f3ee61e4a4a40", null ],
      [ "setPosition", "class_ogre_1_1_billboard.html#a0e78e6b90bbf3184f45d0a87bbeb229b", null ],
      [ "getPosition", "class_ogre_1_1_billboard.html#ae05d9ca75a8fa8b6f2a0fe0c0fa8c748", null ],
      [ "setDimensions", "class_ogre_1_1_billboard.html#a93b6333aff2ef4c3bcf2c426d44dcef1", null ],
      [ "resetDimensions", "class_ogre_1_1_billboard.html#ae5bf31f1d013a1f0c3b5a92e46c76d11", null ],
      [ "setColour", "class_ogre_1_1_billboard.html#a9126c29605e55b8bdb5f81adf267259a", null ],
      [ "getColour", "class_ogre_1_1_billboard.html#ab960e05a2be7d41bbf573932f6075465", null ],
      [ "hasOwnDimensions", "class_ogre_1_1_billboard.html#af51d1dcde1023fb18ee9d3d9e5650625", null ],
      [ "getOwnWidth", "class_ogre_1_1_billboard.html#a5b2103881f1525ba045ee8d8e9a2b1b0", null ],
      [ "getOwnHeight", "class_ogre_1_1_billboard.html#aa55e75efab0444062dce5b2bbd934acd", null ],
      [ "isUseTexcoordRect", "class_ogre_1_1_billboard.html#a3aced837be58b2b578c5cc63b87e01c3", null ],
      [ "setTexcoordIndex", "class_ogre_1_1_billboard.html#ae8aa54c0303721dfc34ebbd8bdf1e8f4", null ],
      [ "getTexcoordIndex", "class_ogre_1_1_billboard.html#a67c55fa7b1487eece36c78bc0148e843", null ],
      [ "setTexcoordRect", "class_ogre_1_1_billboard.html#a22f28d979395f04c6039d46a68c4eefb", null ],
      [ "setTexcoordRect", "class_ogre_1_1_billboard.html#a84d6153b0b9a5f86af082129e6ba0440", null ],
      [ "getTexcoordRect", "class_ogre_1_1_billboard.html#ab492f811d69f1e4e3cae03150f32da90", null ],
      [ "BillboardSet", "class_ogre_1_1_billboard.html#a7f055c0ed81c6b3bef6d154d128093a1", null ],
      [ "BillboardParticleRenderer", "class_ogre_1_1_billboard.html#a261647d2b3ed936e9a2f05309ae878d0", null ],
      [ "mPosition", "class_ogre_1_1_billboard.html#aa7ad6c8789d8589787c4da34c670d66c", null ],
      [ "mDirection", "class_ogre_1_1_billboard.html#a64425b354973d2d957bc878fca407aad", null ],
      [ "mColour", "class_ogre_1_1_billboard.html#aff775f402ef26f494ee5046de9c520e4", null ],
      [ "mRotation", "class_ogre_1_1_billboard.html#ad861053413ca65e059dd74131a084839", null ]
    ] ],
    [ "Ogre::BillboardChain", "class_ogre_1_1_billboard_chain.html", [
      [ "Element", "class_ogre_1_1_billboard_chain_1_1_element.html", [
        [ "Element", "class_ogre_1_1_billboard_chain_1_1_element.html#a68874dd0bbc8cae9ac036dfc45aeec4b", null ],
        [ "Element", "class_ogre_1_1_billboard_chain_1_1_element.html#a77798f9eb4a49fc6b9f1c1e090fb7390", null ],
        [ "position", "class_ogre_1_1_billboard_chain_1_1_element.html#a8ba26812cafc456d1ffcdafba1edc4c7", null ],
        [ "width", "class_ogre_1_1_billboard_chain_1_1_element.html#af9d7a5e7483159c9c5469ed9e9b433f2", null ],
        [ "texCoord", "class_ogre_1_1_billboard_chain_1_1_element.html#ad8e03d7b5242ed921f24ff30c7d7dcf7", null ],
        [ "colour", "class_ogre_1_1_billboard_chain_1_1_element.html#aca293130c8752d30fc6a7bee3252fc36", null ],
        [ "orientation", "class_ogre_1_1_billboard_chain_1_1_element.html#a511a534a85e4accfbbdcb34dc4bcd66c", null ]
      ] ],
      [ "TexCoordDirection", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0ee", [
        [ "TCD_U", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eeab1390d0782b4780e43953c2b166b9cdc", null ],
        [ "TCD_V", "class_ogre_1_1_billboard_chain.html#a92be262f8957455b6fc2adfe9904d0eea8053985a9b153f4dea4ea70db8536782", null ]
      ] ],
      [ "BillboardChain", "class_ogre_1_1_billboard_chain.html#a6b5cba8ae02075702da9f7b2f07d3cc7", null ],
      [ "~BillboardChain", "class_ogre_1_1_billboard_chain.html#adb82bbc7c11e826039d850c1f911cdb7", null ],
      [ "setMaxChainElements", "class_ogre_1_1_billboard_chain.html#a9dfb228583ad5b4d5ddecb19e25b58cd", null ],
      [ "getMaxChainElements", "class_ogre_1_1_billboard_chain.html#ac336f36f7e1918987572d7b9120c1eef", null ],
      [ "setNumberOfChains", "class_ogre_1_1_billboard_chain.html#abcc3676539b5c73bc86039e0f4074124", null ],
      [ "getNumberOfChains", "class_ogre_1_1_billboard_chain.html#af6eb60f312cce1166cfab0fe3e7205f3", null ],
      [ "setUseTextureCoords", "class_ogre_1_1_billboard_chain.html#ae2873540c27dddd3062af468d6fa8d83", null ],
      [ "getUseTextureCoords", "class_ogre_1_1_billboard_chain.html#a18b96a4f14e7a49b21a423fe0e355891", null ],
      [ "setTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#a7b15a6eea809c26455d3ba40c9fffc05", null ],
      [ "getTextureCoordDirection", "class_ogre_1_1_billboard_chain.html#aae77ad0e6c295ecf6ac088b1a9f2ce8c", null ],
      [ "setOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acd94644ca5489ade2cdf28c906c5f042", null ],
      [ "getOtherTextureCoordRange", "class_ogre_1_1_billboard_chain.html#acf9fcd373cb3b27521be9b4656534c8d", null ],
      [ "setUseVertexColours", "class_ogre_1_1_billboard_chain.html#a77eaefdad7be8d14b47e6e9f169b6617", null ],
      [ "getUseVertexColours", "class_ogre_1_1_billboard_chain.html#acfd03b8e57fe6a8b5196a270c6f1bdfd", null ],
      [ "setAutoUpdate", "class_ogre_1_1_billboard_chain.html#a2b3de8a55c12a02a8a07906372c24f0a", null ],
      [ "getAutoUpdate", "class_ogre_1_1_billboard_chain.html#ac08f3a22eb7f8526824158877e41bff5", null ],
      [ "addChainElement", "class_ogre_1_1_billboard_chain.html#a0a153e4f3a350248a53ab5e7382aae8d", null ],
      [ "removeChainElement", "class_ogre_1_1_billboard_chain.html#a86bd2530a15622dbb26aba8a9759b0d3", null ],
      [ "updateChainElement", "class_ogre_1_1_billboard_chain.html#ae3a6efc533be5309cf5274a7aa6a88db", null ],
      [ "getChainElement", "class_ogre_1_1_billboard_chain.html#afe208f1c230dc69b02e118417892f122", null ],
      [ "getNumChainElements", "class_ogre_1_1_billboard_chain.html#a4951ee94b8cdece4d6e7d3d0e6641167", null ],
      [ "clearChain", "class_ogre_1_1_billboard_chain.html#ae940e13fbd86e4f7555d613945b29f5a", null ],
      [ "clearAllChains", "class_ogre_1_1_billboard_chain.html#a38c7e0e727eede17350ca927202bc45c", null ],
      [ "setFaceCamera", "class_ogre_1_1_billboard_chain.html#a3039063ea009d11949489c1cd5a0d0be", null ],
      [ "getMaterialName", "class_ogre_1_1_billboard_chain.html#af4ef9118deb3a2b1aa6d17914fe45201", null ],
      [ "setMaterialName", "class_ogre_1_1_billboard_chain.html#afbfba68f0e99d3bac382b3c7b53e571c", null ],
      [ "getSquaredViewDepth", "class_ogre_1_1_billboard_chain.html#a52cfadc750f094846260d435c4ba39dc", null ],
      [ "getBoundingRadius", "class_ogre_1_1_billboard_chain.html#a8422a07813467a2f5247134a3b082a63", null ],
      [ "getBoundingBox", "class_ogre_1_1_billboard_chain.html#a895c37a20cf12bc8d60ebf9402ddad4e", null ],
      [ "getMaterial", "class_ogre_1_1_billboard_chain.html#a7c217aee1ef230710cb0e97e3936e697", null ],
      [ "getMovableType", "class_ogre_1_1_billboard_chain.html#a2b80cfc5f391e51a2f1c8fade7d97f36", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_billboard_chain.html#a0653cf3c578108cbc2efba177353c552", null ],
      [ "getRenderOperation", "class_ogre_1_1_billboard_chain.html#a56ae0f5fbc72c79a63ed35854ca7dd2e", null ],
      [ "preRender", "class_ogre_1_1_billboard_chain.html#af51ca4a5390cb127936373c419432313", null ],
      [ "getWorldTransforms", "class_ogre_1_1_billboard_chain.html#a4f3f3039677481e19f1d792d3908f56d", null ],
      [ "getLights", "class_ogre_1_1_billboard_chain.html#a7cf77f7b2fbd54dd12b9ab6e5db6df56", null ],
      [ "visitRenderables", "class_ogre_1_1_billboard_chain.html#a30be47f66404d9692021316c3823dd86", null ]
    ] ],
    [ "Ogre::BillboardParticleRenderer", "class_ogre_1_1_billboard_particle_renderer.html", [
      [ "BillboardParticleRenderer", "class_ogre_1_1_billboard_particle_renderer.html#a2803a14ff48f1aa9bfa3ce9526578ee4", null ],
      [ "~BillboardParticleRenderer", "class_ogre_1_1_billboard_particle_renderer.html#a3bb35a6359b5e33120960969a5b3ba3b", null ],
      [ "setTextureStacksAndSlices", "class_ogre_1_1_billboard_particle_renderer.html#a3839712d53d227a466a7021c3dbc6e8d", null ],
      [ "getTextureStacksAndSlices", "class_ogre_1_1_billboard_particle_renderer.html#a7bfaa788a5a777a38b479712a69dc39f", null ],
      [ "setBillboardType", "class_ogre_1_1_billboard_particle_renderer.html#af16e29a945f427d11b89bc761a950767", null ],
      [ "getBillboardType", "class_ogre_1_1_billboard_particle_renderer.html#a3f8a09b144e61c6a711f21d895a9dbec", null ],
      [ "setUseAccurateFacing", "class_ogre_1_1_billboard_particle_renderer.html#a372edf0872962d0364ed9a9b6d5b7b94", null ],
      [ "getUseAccurateFacing", "class_ogre_1_1_billboard_particle_renderer.html#ab5fb40b7a3df2e6ba51ecf8f3d3280ce", null ],
      [ "setBillboardOrigin", "class_ogre_1_1_billboard_particle_renderer.html#aefc6f76117519469b8bc5715966bfe9e", null ],
      [ "getBillboardOrigin", "class_ogre_1_1_billboard_particle_renderer.html#a151a915190cb1e47980975823758a3bc", null ],
      [ "setBillboardRotationType", "class_ogre_1_1_billboard_particle_renderer.html#a5f3c1e209d5b28b71e34fc390e55c33c", null ],
      [ "getBillboardRotationType", "class_ogre_1_1_billboard_particle_renderer.html#a8512a58ed6c0de9d7c8886031afae52f", null ],
      [ "setCommonDirection", "class_ogre_1_1_billboard_particle_renderer.html#ae7af00d85d0902c57c16efac03e6ca27", null ],
      [ "getCommonDirection", "class_ogre_1_1_billboard_particle_renderer.html#a19848b0fa3bd29737140935fbea43178", null ],
      [ "setCommonUpVector", "class_ogre_1_1_billboard_particle_renderer.html#ad2c4b38ae17677ba56b8ab59ad8f502f", null ],
      [ "getCommonUpVector", "class_ogre_1_1_billboard_particle_renderer.html#aacb9e16ac37ceaed9a2ec095d7519ea2", null ],
      [ "setPointRenderingEnabled", "class_ogre_1_1_billboard_particle_renderer.html#a6595f8d0a5404812e01eb1518f3a5186", null ],
      [ "isPointRenderingEnabled", "class_ogre_1_1_billboard_particle_renderer.html#ad6ea7b4e353ae29c81d99b4f3b3a95fb", null ],
      [ "getType", "class_ogre_1_1_billboard_particle_renderer.html#a29c4db641002df3db2a685876356a314", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_billboard_particle_renderer.html#a289355a2a13171d452a71a7fb693768e", null ],
      [ "visitRenderables", "class_ogre_1_1_billboard_particle_renderer.html#a3d0aa10cc88849451d5af842bd820c85", null ],
      [ "_setMaterial", "class_ogre_1_1_billboard_particle_renderer.html#a1acc972c0a4443f404480d267c79e818", null ],
      [ "_notifyCurrentCamera", "class_ogre_1_1_billboard_particle_renderer.html#a3023d225e31f3488e1fb45dc0b775d17", null ],
      [ "_notifyParticleQuota", "class_ogre_1_1_billboard_particle_renderer.html#a41e0ea622cb965288867a40102dbfe73", null ],
      [ "_notifyAttached", "class_ogre_1_1_billboard_particle_renderer.html#aeb4eebb926e43ac2e04454fc84a18587", null ],
      [ "_notifyDefaultDimensions", "class_ogre_1_1_billboard_particle_renderer.html#a28fc897d37ba2e6f2ca70c592814c724", null ],
      [ "setRenderQueueGroup", "class_ogre_1_1_billboard_particle_renderer.html#aeba9b64355259f13e2de62165a4af641", null ],
      [ "setRenderQueueGroupAndPriority", "class_ogre_1_1_billboard_particle_renderer.html#a24680ee4e042d2c0398b08b1f2281d60", null ],
      [ "setKeepParticlesInLocalSpace", "class_ogre_1_1_billboard_particle_renderer.html#a34c3014533825fd113c072adf52108a0", null ],
      [ "_getSortMode", "class_ogre_1_1_billboard_particle_renderer.html#a919306c276f77efff23643d84f2c1d03", null ],
      [ "getBillboardSet", "class_ogre_1_1_billboard_particle_renderer.html#a9b4f0d54b3d81eb5131c5483680df7d0", null ],
      [ "_notifyBoundingBox", "class_ogre_1_1_billboard_particle_renderer.html#a6e3b4c85c72b5ddd8f2dfff6879e6e16", null ],
      [ "_notifyCastShadows", "class_ogre_1_1_billboard_particle_renderer.html#afe6a3f68ac8a1a1439bbcb51ca5bd2cc", null ]
    ] ],
    [ "Ogre::BillboardParticleRendererFactory", "class_ogre_1_1_billboard_particle_renderer_factory.html", [
      [ "getType", "class_ogre_1_1_billboard_particle_renderer_factory.html#ac9c509214c7b02ff2f9eef7485d808f1", null ],
      [ "createInstance", "class_ogre_1_1_billboard_particle_renderer_factory.html#a0fd148a3122729dd615bc1cec595dd95", null ]
    ] ],
    [ "Ogre::BillboardSet", "class_ogre_1_1_billboard_set.html", [
      [ "BillboardSet", "class_ogre_1_1_billboard_set.html#aeec5b589313287f70b8ca0c4fbf7a42c", null ],
      [ "~BillboardSet", "class_ogre_1_1_billboard_set.html#a1cfefe60d202aec234cb322c6a37c175", null ],
      [ "createBillboard", "class_ogre_1_1_billboard_set.html#a7a2fbd8f8fd542e85cbf69692ff60ac7", null ],
      [ "createBillboard", "class_ogre_1_1_billboard_set.html#a9ae5fe251e76430cdfca5d7bc65f3a90", null ],
      [ "getNumBillboards", "class_ogre_1_1_billboard_set.html#ab66bd4ddf7ae59cc08c5056a1854bff5", null ],
      [ "setAutoextend", "class_ogre_1_1_billboard_set.html#a8c7fef26cf426dd9232749bfdd9cdb9c", null ],
      [ "getAutoextend", "class_ogre_1_1_billboard_set.html#a0f6a41f96a7139d0c90a3c38eace8eaf", null ],
      [ "setSortingEnabled", "class_ogre_1_1_billboard_set.html#a7c75366d0efd759178bcea78750fbd84", null ],
      [ "getSortingEnabled", "class_ogre_1_1_billboard_set.html#a73f6382141bf485b22ec3feac5e4d562", null ],
      [ "setPoolSize", "class_ogre_1_1_billboard_set.html#a2db4e54bd3c392fd0d600c49ad4f985d", null ],
      [ "getPoolSize", "class_ogre_1_1_billboard_set.html#a9f291806a1a1f7e06fc78dd3bc33107c", null ],
      [ "clear", "class_ogre_1_1_billboard_set.html#a0cb561eb6225784d7f1cc2fc769eea54", null ],
      [ "getBillboard", "class_ogre_1_1_billboard_set.html#abd3c30f24a7406bb99ee07840e13bff8", null ],
      [ "removeBillboard", "class_ogre_1_1_billboard_set.html#a5b5ced6ee39f322c7e33906072104ffb", null ],
      [ "removeBillboard", "class_ogre_1_1_billboard_set.html#a404ecea90a526757fe5df09c8e2b948d", null ],
      [ "setBillboardOrigin", "class_ogre_1_1_billboard_set.html#a429a4c2aaf93ecf4c6a47d05f40fe929", null ],
      [ "getBillboardOrigin", "class_ogre_1_1_billboard_set.html#a2a2afb79b942c28bf1bd843d08536764", null ],
      [ "setBillboardRotationType", "class_ogre_1_1_billboard_set.html#a04a23ce51cbc7e414fa382f6141e51d7", null ],
      [ "getBillboardRotationType", "class_ogre_1_1_billboard_set.html#a81487620bb49cf36daebeb359e350b82", null ],
      [ "setDefaultDimensions", "class_ogre_1_1_billboard_set.html#a7f7734d477b110d49957e14656249615", null ],
      [ "setDefaultWidth", "class_ogre_1_1_billboard_set.html#ada74916885c8a51dcf6c6f45512ae487", null ],
      [ "getDefaultWidth", "class_ogre_1_1_billboard_set.html#aeefa055932c165695bb4375f143d833c", null ],
      [ "setDefaultHeight", "class_ogre_1_1_billboard_set.html#aefdf60d0bc51fb2df339c44f2058b688", null ],
      [ "getDefaultHeight", "class_ogre_1_1_billboard_set.html#a6974eaf97156f0137cde1f45cbb5db47", null ],
      [ "setMaterialName", "class_ogre_1_1_billboard_set.html#a7a75cccf0a232780b44e9e11c61e96f7", null ],
      [ "getMaterialName", "class_ogre_1_1_billboard_set.html#a4dd1883070b2d5ab9dfa5de96c10e393", null ],
      [ "_notifyCurrentCamera", "class_ogre_1_1_billboard_set.html#a11c0f8d1c57ada00f663b9ec55ac3254", null ],
      [ "beginBillboards", "class_ogre_1_1_billboard_set.html#a69f0f4886b64c86cb02dcb422ea56a40", null ],
      [ "injectBillboard", "class_ogre_1_1_billboard_set.html#a3d2328a30c83c2377893e47eeca56501", null ],
      [ "endBillboards", "class_ogre_1_1_billboard_set.html#a99d782a5d4c290bf6d4c29a41ff4bfc4", null ],
      [ "setBounds", "class_ogre_1_1_billboard_set.html#a728549349f0eb735edea794d0686edd6", null ],
      [ "getBoundingBox", "class_ogre_1_1_billboard_set.html#a06f9d6138a5740e6a05d018a6b45e534", null ],
      [ "getBoundingRadius", "class_ogre_1_1_billboard_set.html#a6ab7afed09300617652a87102c3a1c5a", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_billboard_set.html#a9e9700ab579d661e4b0bd5c5ede303ee", null ],
      [ "getMaterial", "class_ogre_1_1_billboard_set.html#ac5d2ba3e33881970864a82762b86e7ef", null ],
      [ "setMaterial", "class_ogre_1_1_billboard_set.html#a1361b42bd52f3cb7dd58de9df519930c", null ],
      [ "getRenderOperation", "class_ogre_1_1_billboard_set.html#a1bfc7e2a236fc778024297c44946b0d1", null ],
      [ "getWorldTransforms", "class_ogre_1_1_billboard_set.html#aa7d8cc7477432dedac9e22902c573592", null ],
      [ "getCullIndividually", "class_ogre_1_1_billboard_set.html#ac1f9d1451a19e4a06723e7a3f609317c", null ],
      [ "setCullIndividually", "class_ogre_1_1_billboard_set.html#add88630589a71436d1c666853a00c3c3", null ],
      [ "setBillboardType", "class_ogre_1_1_billboard_set.html#a8a11b601acc868a63d4be78b1a81ba7e", null ],
      [ "getBillboardType", "class_ogre_1_1_billboard_set.html#a3aa65ef393ef9df588dc1d3f2ef5e9cb", null ],
      [ "setCommonDirection", "class_ogre_1_1_billboard_set.html#af45bb52930ecc2331ed52b4b95d2254f", null ],
      [ "getCommonDirection", "class_ogre_1_1_billboard_set.html#a01e06ca832cd24967aedc1514b84b185", null ],
      [ "setCommonUpVector", "class_ogre_1_1_billboard_set.html#a050415f45ae30e527dbc649054d814f7", null ],
      [ "getCommonUpVector", "class_ogre_1_1_billboard_set.html#a2c403565e026d8773d86b864b71254ae", null ],
      [ "setUseAccurateFacing", "class_ogre_1_1_billboard_set.html#a0353cb5f4fb37601d7371ca6971e7c1c", null ],
      [ "getUseAccurateFacing", "class_ogre_1_1_billboard_set.html#aabae95a7d08ff43bce4c636e2af02ceb", null ],
      [ "getMovableType", "class_ogre_1_1_billboard_set.html#a8c9909bf2a287b733c1dfb13f2124234", null ],
      [ "getSquaredViewDepth", "class_ogre_1_1_billboard_set.html#a5b3be98132fbab3edefa4f58b0e17629", null ],
      [ "_updateBounds", "class_ogre_1_1_billboard_set.html#a18c2b6d664dbdaee73336272be76aeee", null ],
      [ "getLights", "class_ogre_1_1_billboard_set.html#ae084a597def570f233dc93c3b0e83ca6", null ],
      [ "visitRenderables", "class_ogre_1_1_billboard_set.html#a566fce3ab6c5c5d809ffa13e1ba65a79", null ],
      [ "_sortBillboards", "class_ogre_1_1_billboard_set.html#af903717c84e7408531157acbe031a1f7", null ],
      [ "_getSortMode", "class_ogre_1_1_billboard_set.html#a199afd1c34f5fa898b78f32caf6b5c19", null ],
      [ "setBillboardsInWorldSpace", "class_ogre_1_1_billboard_set.html#a3fdc80cf6163137bd989a28308c32532", null ],
      [ "getBillboardsInWorldSpace", "class_ogre_1_1_billboard_set.html#a6d327135adcfd4325b3c3d545a5727e9", null ],
      [ "setTextureCoords", "class_ogre_1_1_billboard_set.html#acdd0380c8f19501bedad533479e4405c", null ],
      [ "setTextureCoords", "class_ogre_1_1_billboard_set.html#acedaa7b644b77d3085ba0d40fda1ce95", null ],
      [ "setTextureStacksAndSlices", "class_ogre_1_1_billboard_set.html#a46d0c8af03b5442ce8a05629ad38a27e", null ],
      [ "getTextureCoords", "class_ogre_1_1_billboard_set.html#ade12a45d3ec2288652dadbf858d0c486", null ],
      [ "setPointRenderingEnabled", "class_ogre_1_1_billboard_set.html#a417ba29ab7894f7ba4fda41bbd8cf3b6", null ],
      [ "isPointRenderingEnabled", "class_ogre_1_1_billboard_set.html#a17029102e99f556d6e9b2779f3e93068", null ],
      [ "getTypeFlags", "class_ogre_1_1_billboard_set.html#adafd315fd5322aca17011c3de95001c3", null ],
      [ "setAutoUpdate", "class_ogre_1_1_billboard_set.html#afee8dbd0c4132378b1659ebc83400d5f", null ],
      [ "getAutoUpdate", "class_ogre_1_1_billboard_set.html#a02c237069711dbb75086bd0d39a682e6", null ],
      [ "notifyBillboardDataChanged", "class_ogre_1_1_billboard_set.html#aa0306902ff175409c288e8f7be67f999", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_billboard_set.html#ae7b65f76a332295aac37ba1605b6ec96", null ]
    ] ],
    [ "Ogre::CompositionPass", "class_ogre_1_1_composition_pass.html", [
      [ "InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html", [
        [ "InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html#a5f5c8dbdb4aabf1584453cefb997ae03", null ],
        [ "InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html#a0c02e4a4e46c29f23af2e5cfdd4e01aa", null ],
        [ "name", "struct_ogre_1_1_composition_pass_1_1_input_tex.html#a549645d3640226a6cbd2bdb3d4f29d59", null ],
        [ "mrtIndex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html#afb900befa1a297701c434ccc65d3d810", null ]
      ] ],
      [ "PassType", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aa", [
        [ "PT_CLEAR", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaa7d4ed28ab9cdd43e85a715bd4e068fc", null ],
        [ "PT_STENCIL", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa43301dad285fba17915d7867665597ab", null ],
        [ "PT_RENDERSCENE", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaac8aa60611671e1b8867c1a30775ba84c", null ],
        [ "PT_RENDERQUAD", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa39b1d2658f5c73b04755e428316ea366", null ],
        [ "PT_RENDERCUSTOM", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaba93db3e2878858fe2fd199354c82af9", null ],
        [ "PT_COMPUTE", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaafa19263d8a14d62c4aec06a1dd14f6ed", null ]
      ] ],
      [ "CompositionPass", "class_ogre_1_1_composition_pass.html#a5b5540cb8dc10175dc30c3947032013c", null ],
      [ "~CompositionPass", "class_ogre_1_1_composition_pass.html#ab8fc137845790b360d57056621cd1061", null ],
      [ "setType", "class_ogre_1_1_composition_pass.html#a8b0e3dcfccbdcc9672a96ae6dc2c0123", null ],
      [ "getType", "class_ogre_1_1_composition_pass.html#a6a51eff0938089a5fc26c1bec5c3778f", null ],
      [ "setIdentifier", "class_ogre_1_1_composition_pass.html#a56bb1d899a43195712944398e2d1bc65", null ],
      [ "getIdentifier", "class_ogre_1_1_composition_pass.html#ab60bfaaed2a48057ac8e8e7ead113f60", null ],
      [ "setMaterial", "class_ogre_1_1_composition_pass.html#a21721f49c3b10e36560adff1e563740f", null ],
      [ "setMaterialName", "class_ogre_1_1_composition_pass.html#a453231b980fc04dd9af9f330feec5236", null ],
      [ "getMaterial", "class_ogre_1_1_composition_pass.html#a5db4dfa2b32f8b30b9287756a814ad17", null ],
      [ "setFirstRenderQueue", "class_ogre_1_1_composition_pass.html#a4af9e5a958c5ec3a69f8bd797d4c2563", null ],
      [ "getFirstRenderQueue", "class_ogre_1_1_composition_pass.html#ab7f667605829412a22d0cccd9c1d7e6c", null ],
      [ "setLastRenderQueue", "class_ogre_1_1_composition_pass.html#a193d54ee08e19d538576ca300c30c006", null ],
      [ "getLastRenderQueue", "class_ogre_1_1_composition_pass.html#a1947a2e49e4c78d3fa806933690e6522", null ],
      [ "setMaterialScheme", "class_ogre_1_1_composition_pass.html#afdc03ddab7dba7ca065345a0ab5351fd", null ],
      [ "getMaterialScheme", "class_ogre_1_1_composition_pass.html#a86caf21c89bd21cd24556835081eb7fd", null ],
      [ "setClearBuffers", "class_ogre_1_1_composition_pass.html#a92187a460af36b8ebe0828cf6d81c277", null ],
      [ "getClearBuffers", "class_ogre_1_1_composition_pass.html#a86b647f3dff3e2fc021302c23827b603", null ],
      [ "setClearColour", "class_ogre_1_1_composition_pass.html#a749020e95d4cd6d908983d042b86e429", null ],
      [ "getClearColour", "class_ogre_1_1_composition_pass.html#ad61c6f3a0d1dfe3a723767a1a95427fd", null ],
      [ "setAutomaticColour", "class_ogre_1_1_composition_pass.html#ad72002d4220edc51b6ac40bbd811cbee", null ],
      [ "getAutomaticColour", "class_ogre_1_1_composition_pass.html#ac4fae76a4f67e1ea70dc270be9b0daed", null ],
      [ "setClearDepth", "class_ogre_1_1_composition_pass.html#af3d7bb3afd593a8a6d9415cec6c39583", null ],
      [ "getClearDepth", "class_ogre_1_1_composition_pass.html#ab83f915d669abd8efd4d63cbbff4c168", null ],
      [ "setClearStencil", "class_ogre_1_1_composition_pass.html#a5ad3b98ebaf06fd085155d81c69eeef5", null ],
      [ "getClearStencil", "class_ogre_1_1_composition_pass.html#af55a03aab77873e0e6d637cf81371559", null ],
      [ "setStencilCheck", "class_ogre_1_1_composition_pass.html#af0f6a55176e7c69fda820a5d22a50104", null ],
      [ "getStencilCheck", "class_ogre_1_1_composition_pass.html#a31e5b47326f6357b7172faca282cb3ea", null ],
      [ "setStencilFunc", "class_ogre_1_1_composition_pass.html#a7d60b3d8f6e47891d8e5373bea31d5bd", null ],
      [ "getStencilFunc", "class_ogre_1_1_composition_pass.html#a14fcb5fbfd45871dca725c88de5a83a5", null ],
      [ "setStencilRefValue", "class_ogre_1_1_composition_pass.html#a1b8cc0c3221bfbc751328cda98c8aff7", null ],
      [ "getStencilRefValue", "class_ogre_1_1_composition_pass.html#a2fd6b67d996e8a9c9a7b8443490e997e", null ],
      [ "setStencilMask", "class_ogre_1_1_composition_pass.html#a052e16876215e11e03bcba8657faf917", null ],
      [ "getStencilMask", "class_ogre_1_1_composition_pass.html#af347ecd30bdb07219cb1794599b30ec7", null ],
      [ "setStencilFailOp", "class_ogre_1_1_composition_pass.html#ad7afd96369d5093b5eb2123f2befed58", null ],
      [ "getStencilFailOp", "class_ogre_1_1_composition_pass.html#a354620f0bec90c923b57707019195483", null ],
      [ "setStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#ae3c196d705b7bf120e0d888b4867dda4", null ],
      [ "getStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#adcd852af123434d7ff154a2569121d27", null ],
      [ "setStencilPassOp", "class_ogre_1_1_composition_pass.html#aff4417885952905fc8230cef47a36756", null ],
      [ "getStencilPassOp", "class_ogre_1_1_composition_pass.html#a6e14a28e603b902ee0794f78912f329f", null ],
      [ "setStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#afa3d6c2f5f8e6ba85b7844d2bf433a5f", null ],
      [ "getStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#a45657514c52a86f22d9d575fa248de0a", null ],
      [ "getStencilState", "class_ogre_1_1_composition_pass.html#a40ab88e0a239182e4b3071af7d28179b", null ],
      [ "setInput", "class_ogre_1_1_composition_pass.html#afa546e1e7d46879c3dc6ce5dff470d4d", null ],
      [ "getInput", "class_ogre_1_1_composition_pass.html#aac9b21d429d70081fee566fbc9b978a9", null ],
      [ "getNumInputs", "class_ogre_1_1_composition_pass.html#a88aed71c3c005bea6be70c8d58db3232", null ],
      [ "clearAllInputs", "class_ogre_1_1_composition_pass.html#a05cbca68fbc408dbf755612cfb72707d", null ],
      [ "getParent", "class_ogre_1_1_composition_pass.html#a8fdd69a67ba251fcffbf04d1496ccb63", null ],
      [ "_isSupported", "class_ogre_1_1_composition_pass.html#ac0daef1d307ace963959896a3db64d75", null ],
      [ "setQuadCorners", "class_ogre_1_1_composition_pass.html#a58915b98148aef94f7bc887983db41d3", null ],
      [ "getQuadCorners", "class_ogre_1_1_composition_pass.html#ab80f5bdd57e0c746293bdd5a9f3adef2", null ],
      [ "setQuadFarCorners", "class_ogre_1_1_composition_pass.html#ac2831cd42c94887f6e239d1460dc6b5c", null ],
      [ "getQuadFarCorners", "class_ogre_1_1_composition_pass.html#ae350fcee79e006e23d6de413253568e5", null ],
      [ "getQuadFarCornersViewSpace", "class_ogre_1_1_composition_pass.html#a88bc728d5e0497ce4c5dbc052239551d", null ],
      [ "setCustomType", "class_ogre_1_1_composition_pass.html#a0937b1f59f584797d44383eeb44b30eb", null ],
      [ "getCustomType", "class_ogre_1_1_composition_pass.html#adb9a1389283be682baf5cb41e20cc3c7", null ],
      [ "setThreadGroups", "class_ogre_1_1_composition_pass.html#a646a9f816b1e91a925e52af74570fe11", null ],
      [ "getThreadGroups", "class_ogre_1_1_composition_pass.html#a60ab9739bc4cc02711cabfd3dffad505", null ],
      [ "setCameraName", "class_ogre_1_1_composition_pass.html#a3c841ec10a29439573bff56f425dcdac", null ],
      [ "getCameraName", "class_ogre_1_1_composition_pass.html#a3a5a37066fab2d012d83acdc4885144f", null ],
      [ "setAlignCameraToFace", "class_ogre_1_1_composition_pass.html#a892fd8d11f15e33fcfda68b891a82105", null ],
      [ "getAlignCameraToFace", "class_ogre_1_1_composition_pass.html#a9b1581d87604d9a3698916ac7fe9796c", null ]
    ] ],
    [ "Ogre::CompositionTargetPass", "class_ogre_1_1_composition_target_pass.html", [
      [ "Passes", "class_ogre_1_1_composition_target_pass.html#adde9a7cf6d9cf64e1ad3115f25625748", null ],
      [ "PassIterator", "class_ogre_1_1_composition_target_pass.html#a1b8ac16663ae6c9fc06c80159f87d51b", null ],
      [ "InputMode", "class_ogre_1_1_composition_target_pass.html#ab2b5ca61fda0a8dfdba1e3447f453294", [
        [ "IM_NONE", "class_ogre_1_1_composition_target_pass.html#ab2b5ca61fda0a8dfdba1e3447f453294a97eecad4dbc7cc768152365585fa9fe6", null ],
        [ "IM_PREVIOUS", "class_ogre_1_1_composition_target_pass.html#ab2b5ca61fda0a8dfdba1e3447f453294a412bc35d7930bd2101ea4d0a5a760611", null ]
      ] ],
      [ "CompositionTargetPass", "class_ogre_1_1_composition_target_pass.html#a612ca8c0c7b29fe33def25042b933622", null ],
      [ "~CompositionTargetPass", "class_ogre_1_1_composition_target_pass.html#a9906c9ece49a038ff4996ff461238dd4", null ],
      [ "setInputMode", "class_ogre_1_1_composition_target_pass.html#abf1c9cf0c11f8f440bfb1103b6c1349a", null ],
      [ "getInputMode", "class_ogre_1_1_composition_target_pass.html#af39146bee5214ac96262015eee849e64", null ],
      [ "setOutputName", "class_ogre_1_1_composition_target_pass.html#ac9a67dacd9d95d9f91fdb9437b07d758", null ],
      [ "getOutputName", "class_ogre_1_1_composition_target_pass.html#a10bb0b0e8ed6b7699a2d81086e04d4be", null ],
      [ "setOutputSlice", "class_ogre_1_1_composition_target_pass.html#ae9dd727231b1e2c8fa1da9b50ab9a13d", null ],
      [ "getOutputSlice", "class_ogre_1_1_composition_target_pass.html#acbec312ceabb59e41b42aab4a22e640c", null ],
      [ "setOnlyInitial", "class_ogre_1_1_composition_target_pass.html#aa4113fff3ebd783e8ead645321cb7322", null ],
      [ "getOnlyInitial", "class_ogre_1_1_composition_target_pass.html#ab966f6bbb58d0d0a09c478fa20ded7c4", null ],
      [ "setVisibilityMask", "class_ogre_1_1_composition_target_pass.html#a5f741ec104a602e81d3f9b5f01ae2d4c", null ],
      [ "getVisibilityMask", "class_ogre_1_1_composition_target_pass.html#aae200cd1a0e12a84df5355f08ee06995", null ],
      [ "setMaterialScheme", "class_ogre_1_1_composition_target_pass.html#a3f57dcb06d3d764e4fe532be89e6f350", null ],
      [ "getMaterialScheme", "class_ogre_1_1_composition_target_pass.html#a686c3dcffdb9f4dcb00aee622743af9d", null ],
      [ "setShadowsEnabled", "class_ogre_1_1_composition_target_pass.html#a0a4ee56a29f0aa2ec2131ed9bdda9f4b", null ],
      [ "getShadowsEnabled", "class_ogre_1_1_composition_target_pass.html#ad2b719aea00abc6175f06db684d19e2b", null ],
      [ "setLodBias", "class_ogre_1_1_composition_target_pass.html#aff86d6761429799b8bb58e44962f2a0f", null ],
      [ "getLodBias", "class_ogre_1_1_composition_target_pass.html#a77a7e3bada28e04c2498aff78886d8b8", null ],
      [ "createPass", "class_ogre_1_1_composition_target_pass.html#a5133d1bfe3bbec541917faea2346dddc", null ],
      [ "removePass", "class_ogre_1_1_composition_target_pass.html#a211bcd76961f116969bbc4b1a5d7562d", null ],
      [ "getPass", "class_ogre_1_1_composition_target_pass.html#aec908120c02aa00e6cce0a3951b3a787", null ],
      [ "getNumPasses", "class_ogre_1_1_composition_target_pass.html#ad9a2d69bdac2821c3d07286a076faf35", null ],
      [ "getPasses", "class_ogre_1_1_composition_target_pass.html#a1d5863b5cd90a3e792d729e78c6abbb2", null ],
      [ "removeAllPasses", "class_ogre_1_1_composition_target_pass.html#a0e3250aafe830419fcf6ec9c2a925e6e", null ],
      [ "getPassIterator", "class_ogre_1_1_composition_target_pass.html#a81f81638ed902707871edaa54d570e3c", null ],
      [ "getParent", "class_ogre_1_1_composition_target_pass.html#a1c2811cc27760fe2690fccaa03cf48b6", null ],
      [ "_isSupported", "class_ogre_1_1_composition_target_pass.html#a5e1075c8f2a3c9cfaed6f65a9ea55334", null ]
    ] ],
    [ "Ogre::CompositionTechnique", "class_ogre_1_1_composition_technique.html", [
      [ "TextureDefinition", "class_ogre_1_1_composition_technique_1_1_texture_definition.html", [
        [ "TextureDefinition", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a7e371a5590972522e7f8024295bb8a59", null ],
        [ "name", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a23d1b9553769ca1f4e47175a567fcf0c", null ],
        [ "refCompName", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#ae59f6efc2a9d0bc5cf539c647351848d", null ],
        [ "refTexName", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a438d2780a5dfe0ac83309b0b9e7dde96", null ],
        [ "width", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a46b4ede7400302f6d58e03d1eb4489ae", null ],
        [ "height", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#abbbb4c6b2ea75b413ff5534be536ad73", null ],
        [ "depth", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a961b6a77bc1f93094da60c68ce7124f6", null ],
        [ "type", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a2b3a7551a57b77fde8c23de7267b2056", null ],
        [ "widthFactor", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a5c71286e9daa688d6028deb524c15ddc", null ],
        [ "heightFactor", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b", null ],
        [ "formatList", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#acdc503bc2adeee31d32988c6c994c0d6", null ],
        [ "fsaa", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#af7cf8abd5790419f08b59519b3bb3374", null ],
        [ "hwGammaWrite", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a07a1f192baf1bb43445dd40bbbaef114", null ],
        [ "depthBufferId", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#aa9c8a54bdaa418233c6f10c3a8a2eb98", null ],
        [ "pooled", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a90341172974dbdea53d010c4d5aa90da", null ],
        [ "scope", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a8826739f93ea3bb356c4a1bb5b5b008c", null ]
      ] ],
      [ "TargetPasses", "class_ogre_1_1_composition_technique.html#ae3bc01432cca2866776fc578be61b7b5", null ],
      [ "TargetPassIterator", "class_ogre_1_1_composition_technique.html#a5a54aecf9c72e8323b12d55199308c66", null ],
      [ "TextureDefinitions", "class_ogre_1_1_composition_technique.html#af6b63a9d4592c48d2389525148a334ee", null ],
      [ "TextureDefinitionIterator", "class_ogre_1_1_composition_technique.html#a34f28a53486ea2cee58619b2c1a639fe", null ],
      [ "TextureScope", "class_ogre_1_1_composition_technique.html#a72f5c327008d8292c004bcd5bdf6fb1e", [
        [ "TS_LOCAL", "class_ogre_1_1_composition_technique.html#a72f5c327008d8292c004bcd5bdf6fb1ea6f778889142bb74cc5aefa4f396b386d", null ],
        [ "TS_CHAIN", "class_ogre_1_1_composition_technique.html#a72f5c327008d8292c004bcd5bdf6fb1ea90fc4ed7303d0d5b549dcc1873ddcde7", null ],
        [ "TS_GLOBAL", "class_ogre_1_1_composition_technique.html#a72f5c327008d8292c004bcd5bdf6fb1eaeaa58ffdb5ed352498ce0fa8263bda4d", null ]
      ] ],
      [ "CompositionTechnique", "class_ogre_1_1_composition_technique.html#aed3697e1f5dee4e6e71b03338371dac9", null ],
      [ "~CompositionTechnique", "class_ogre_1_1_composition_technique.html#a3b37aab5a73a19c0c2537b33cea5256e", null ],
      [ "createTextureDefinition", "class_ogre_1_1_composition_technique.html#a6e09bbb7713c430ea48084535252369c", null ],
      [ "removeTextureDefinition", "class_ogre_1_1_composition_technique.html#a4bba82fa0f4e54090a2497fe9f658fab", null ],
      [ "getTextureDefinition", "class_ogre_1_1_composition_technique.html#ad8acad777512f15a6a13799c74b50928", null ],
      [ "getTextureDefinition", "class_ogre_1_1_composition_technique.html#a339f83c94ef006bca465f96e84b421fd", null ],
      [ "getNumTextureDefinitions", "class_ogre_1_1_composition_technique.html#aef09c60a1e9c66d5f140c34651f4d082", null ],
      [ "removeAllTextureDefinitions", "class_ogre_1_1_composition_technique.html#a03d4c71942abef880d9b2c9e363fe259", null ],
      [ "getTextureDefinitions", "class_ogre_1_1_composition_technique.html#a36207721f70745b2aa753f642d699b25", null ],
      [ "getTextureDefinitionIterator", "class_ogre_1_1_composition_technique.html#a07fe9d82291bef342e223b765a88a5f1", null ],
      [ "createTargetPass", "class_ogre_1_1_composition_technique.html#a43d9720f76370f430831493d7679e5dd", null ],
      [ "removeTargetPass", "class_ogre_1_1_composition_technique.html#a13b52dbaf483cd1ab0eec9edbef078e2", null ],
      [ "getTargetPass", "class_ogre_1_1_composition_technique.html#ac67edea386df7673616c0af3e7803804", null ],
      [ "getNumTargetPasses", "class_ogre_1_1_composition_technique.html#a67c5761dc115b3f0e8b3b29e5f6caf26", null ],
      [ "removeAllTargetPasses", "class_ogre_1_1_composition_technique.html#a4b34afd12984d3a5883e24b512c2b4a2", null ],
      [ "getTargetPasses", "class_ogre_1_1_composition_technique.html#ae527127f766e8acd8edd611625edf721", null ],
      [ "getTargetPassIterator", "class_ogre_1_1_composition_technique.html#a472bbfd655c99319514ebc1fc58961c5", null ],
      [ "getOutputTargetPass", "class_ogre_1_1_composition_technique.html#aad01317663cefd8cad87d07dae25c9a3", null ],
      [ "isSupported", "class_ogre_1_1_composition_technique.html#a7395bb89044375bea1be770737651875", null ],
      [ "setSchemeName", "class_ogre_1_1_composition_technique.html#a13d2bcb0ecbd440325621b809becd2c4", null ],
      [ "getSchemeName", "class_ogre_1_1_composition_technique.html#a728de1d2f9adf08f112b203586ec3a9d", null ],
      [ "setCompositorLogicName", "class_ogre_1_1_composition_technique.html#af221a1809b2de447c7036dd356026ad5", null ],
      [ "getCompositorLogicName", "class_ogre_1_1_composition_technique.html#a9267e64eed08ad7567b64a9c0c576903", null ],
      [ "getParent", "class_ogre_1_1_composition_technique.html#a7ff4a62ff713cba88a8d5885a585f69a", null ]
    ] ],
    [ "Ogre::Compositor", "class_ogre_1_1_compositor.html", [
      [ "Techniques", "class_ogre_1_1_compositor.html#a34a3a5086152382d77a85c25fbabb1be", null ],
      [ "TechniqueIterator", "class_ogre_1_1_compositor.html#acc029ae8cf6f0db569d8328621c6cd50", null ],
      [ "Compositor", "class_ogre_1_1_compositor.html#a1f3a6209ce89a4105719c26e0b2a5f46", null ],
      [ "~Compositor", "class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd", null ],
      [ "createTechnique", "class_ogre_1_1_compositor.html#aed7c5f927e625cf58f65a50c9c55abe4", null ],
      [ "removeTechnique", "class_ogre_1_1_compositor.html#aae47eb9cabec8ad5c8b40a0dd0e8180d", null ],
      [ "getTechnique", "class_ogre_1_1_compositor.html#acfdba392e0274fdbd0e4d14948bebc38", null ],
      [ "getNumTechniques", "class_ogre_1_1_compositor.html#af5c1adab5d0aa7bae1374cd971162c8c", null ],
      [ "removeAllTechniques", "class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd", null ],
      [ "getTechniqueIterator", "class_ogre_1_1_compositor.html#a65cd9c6af5f17b32283be24e0b13010f", null ],
      [ "getSupportedTechnique", "class_ogre_1_1_compositor.html#acf1dec61d4fc0b3001ed0cf4eb7e3969", null ],
      [ "getNumSupportedTechniques", "class_ogre_1_1_compositor.html#a7f8ef525639ebc764e0be2dfa1349dfd", null ],
      [ "getSupportedTechniqueIterator", "class_ogre_1_1_compositor.html#a52653a85d40ae889556707320a784d3e", null ],
      [ "getSupportedTechnique", "class_ogre_1_1_compositor.html#aa22940bfe5308327d7f00aea0279deab", null ],
      [ "getTextureInstanceName", "class_ogre_1_1_compositor.html#a74f8cab4f5407b59a30160a1f8309cee", null ],
      [ "getTextureInstance", "class_ogre_1_1_compositor.html#a446dd4a5fed791283a79d6acd9936d55", null ],
      [ "getRenderTarget", "class_ogre_1_1_compositor.html#adf336074a45c59d05b585f0e6f745ed3", null ]
    ] ],
    [ "Ogre::CompositorChain", "class_ogre_1_1_compositor_chain.html", [
      [ "Instances", "class_ogre_1_1_compositor_chain.html#af98b6351f6dcbcbc353e9ec39b3e8d0a", null ],
      [ "InstanceIterator", "class_ogre_1_1_compositor_chain.html#ab6a0110a3e6e1cc2c45a6aa7e6d15e20", null ],
      [ "CompositorChain", "class_ogre_1_1_compositor_chain.html#ac96b3bb0bdc4889c8917ce7015604db1", null ],
      [ "~CompositorChain", "class_ogre_1_1_compositor_chain.html#aa8834cdfc95d460005da8099f2f267be", null ],
      [ "addCompositor", "class_ogre_1_1_compositor_chain.html#afc10e5a9b4eeb71a200a863ae80fdf43", null ],
      [ "removeCompositor", "class_ogre_1_1_compositor_chain.html#a136bcc91dece7d0c020c6bf4e635a2f3", null ],
      [ "getNumCompositors", "class_ogre_1_1_compositor_chain.html#a16acff0bca06c03a0b3664032631dd5f", null ],
      [ "removeAllCompositors", "class_ogre_1_1_compositor_chain.html#a8555577c8789123a52ee4dc88511c06b", null ],
      [ "getCompositor", "class_ogre_1_1_compositor_chain.html#ac8c9717f887efa3234117b8fd259bb3f", null ],
      [ "getCompositor", "class_ogre_1_1_compositor_chain.html#ab50bee7bf2f968e6e735d9197d6b064e", null ],
      [ "getCompositorPosition", "class_ogre_1_1_compositor_chain.html#a8479909addfccc643f09fbe70f70a54e", null ],
      [ "_getOriginalSceneCompositor", "class_ogre_1_1_compositor_chain.html#a546101d3381fcc72904420443a1868ec", null ],
      [ "getCompositorInstances", "class_ogre_1_1_compositor_chain.html#accf44b0ab86da2305e3bb306d827237e", null ],
      [ "getCompositors", "class_ogre_1_1_compositor_chain.html#aedef40765b6893d4451e4abc682b8870", null ],
      [ "setCompositorEnabled", "class_ogre_1_1_compositor_chain.html#a3c2e3610732ee682f97a2e177168ca21", null ],
      [ "preRenderTargetUpdate", "class_ogre_1_1_compositor_chain.html#a2f06c8b7e9bd3ab605c85b7ccbafd78d", null ],
      [ "postRenderTargetUpdate", "class_ogre_1_1_compositor_chain.html#a1495dde8bb681d9f10563a7d3bc90581", null ],
      [ "preViewportUpdate", "class_ogre_1_1_compositor_chain.html#a2bc1594f935675eed1105b7a46a1e534", null ],
      [ "postViewportUpdate", "class_ogre_1_1_compositor_chain.html#ad9d23e67ac7dd8e05fa746c5671c3a1b", null ],
      [ "viewportCameraChanged", "class_ogre_1_1_compositor_chain.html#a525b74c5dce0313660a61fb5e273bf1d", null ],
      [ "viewportDimensionsChanged", "class_ogre_1_1_compositor_chain.html#a4f05209aeabe3a2ccf7c1abccfc168c1", null ],
      [ "viewportDestroyed", "class_ogre_1_1_compositor_chain.html#a0301254bb0cd91ca135805638301ad25", null ],
      [ "_markDirty", "class_ogre_1_1_compositor_chain.html#a0786570dbe0567f781db42c64cdc0864", null ],
      [ "getViewport", "class_ogre_1_1_compositor_chain.html#a1e3e30292bbae6d7191bb1c4b8a4d6fb", null ],
      [ "_notifyViewport", "class_ogre_1_1_compositor_chain.html#a0c5a67e7aeb3f74242a45972f30073eb", null ],
      [ "_removeInstance", "class_ogre_1_1_compositor_chain.html#a9d532a4e514a102d8a2970b5d012707e", null ],
      [ "_queuedOperation", "class_ogre_1_1_compositor_chain.html#a3ca3e8bf062f7b7835043db522e49230", null ],
      [ "_compile", "class_ogre_1_1_compositor_chain.html#ab58b7b39dc6335b196791d73f880f73b", null ],
      [ "getPreviousInstance", "class_ogre_1_1_compositor_chain.html#a3ed439fb8d69d54ba130b603dc8f6c31", null ],
      [ "getNextInstance", "class_ogre_1_1_compositor_chain.html#a9fcea00645f1ed94f074f8d337cc0b0c", null ]
    ] ],
    [ "Ogre::CompositorInstance", "class_ogre_1_1_compositor_instance.html", [
      [ "Listener", "class_ogre_1_1_compositor_instance_1_1_listener.html", [
        [ "~Listener", "class_ogre_1_1_compositor_instance_1_1_listener.html#a82e8895563c0105986b247d973902e1d", null ],
        [ "notifyMaterialSetup", "class_ogre_1_1_compositor_instance_1_1_listener.html#a487a34865d41776e7ff9f42b4bcf7422", null ],
        [ "notifyMaterialRender", "class_ogre_1_1_compositor_instance_1_1_listener.html#a4234db3c8711ea3f253b98b13ece8f2e", null ],
        [ "notifyResourcesCreated", "class_ogre_1_1_compositor_instance_1_1_listener.html#a676b698ff66347981e632977b34de693", null ],
        [ "notifyResourcesReleased", "class_ogre_1_1_compositor_instance_1_1_listener.html#aeaa3d5a5b77a17f9701c91341ee50e1b", null ]
      ] ],
      [ "RenderSystemOperation", "class_ogre_1_1_compositor_instance_1_1_render_system_operation.html", [
        [ "~RenderSystemOperation", "class_ogre_1_1_compositor_instance_1_1_render_system_operation.html#abfaf6ab6afaeb98e9a0deaafb43bad49", null ],
        [ "execute", "class_ogre_1_1_compositor_instance_1_1_render_system_operation.html#a71298b4165d15e5e4abf5239690d09ab", null ]
      ] ],
      [ "TargetOperation", "class_ogre_1_1_compositor_instance_1_1_target_operation.html", [
        [ "RenderQueueBitSet", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a7026db7788bde13a6b6466a967733b64", null ],
        [ "TargetOperation", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#ae830521a3572e0c30c145e9e74c779de", null ],
        [ "TargetOperation", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a4a07f4c5f9abe2a6f760f612434db34f", null ],
        [ "target", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#af5c5f5aab22a31e194c2bba815d01b49", null ],
        [ "currentQueueGroupID", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#af87bc9636c803efa26fbcc4f5a4fa063", null ],
        [ "renderSystemOperations", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a91205dfe635e89525f6080c93a913522", null ],
        [ "visibilityMask", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#aa068061eb691af0d3b0ff440004221a8", null ],
        [ "lodBias", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a8ba9a8940b2e81cb3e866cce28697a4f", null ],
        [ "renderQueues", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a4d359b9d7ce499be7c9e72e62a0a5787", null ],
        [ "onlyInitial", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a56bb029bcccd70874ba6474e66393fdd", null ],
        [ "hasBeenRendered", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a29e5d3e3b946b36d3b253d78e3a66b89", null ],
        [ "findVisibleObjects", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a09330d104546144ccb1ff53510fb826a", null ],
        [ "materialScheme", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#ac5258ce0ba7b24c2854ec37543daa59f", null ],
        [ "shadowsEnabled", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#ac130ef8cace8c4af74ba60f37deb25fe", null ],
        [ "cameraOverride", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a34bc78096837ffec607502b4d9b04da6", null ],
        [ "alignCameraToFace", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a9f0ff12a7501fa0668d6ede6e18a913f", null ]
      ] ],
      [ "RenderSystemOpPair", "class_ogre_1_1_compositor_instance.html#ab03be79964e60192fc2d4446b81b29fe", null ],
      [ "RenderSystemOpPairs", "class_ogre_1_1_compositor_instance.html#abe1fafc9b94e4833ec62ce008c3a2bd6", null ],
      [ "CompiledState", "class_ogre_1_1_compositor_instance.html#a542cbb4277495b83ae702f991c599779", null ],
      [ "CompositorInstance", "class_ogre_1_1_compositor_instance.html#a39c9140067caf225bbd8adfd9460ef75", null ],
      [ "~CompositorInstance", "class_ogre_1_1_compositor_instance.html#ac31217edeab3160905ec1e367eda7c17", null ],
      [ "setEnabled", "class_ogre_1_1_compositor_instance.html#a2d4798f79dc9cce935815344e8d1bd85", null ],
      [ "getEnabled", "class_ogre_1_1_compositor_instance.html#abf6f98964234eee4e0949af8580ce537", null ],
      [ "setAlive", "class_ogre_1_1_compositor_instance.html#ac3c4c1468f7c84586faf39f9e96b933e", null ],
      [ "getAlive", "class_ogre_1_1_compositor_instance.html#a87f0c24e8d4d7aa7dd4a706a6f723ef2", null ],
      [ "getTextureInstanceName", "class_ogre_1_1_compositor_instance.html#a43cdb26919273b0ec8a69c5232113688", null ],
      [ "getTextureInstance", "class_ogre_1_1_compositor_instance.html#a45818a9a03ef4ef8405a4a1ef4b85027", null ],
      [ "getRenderTarget", "class_ogre_1_1_compositor_instance.html#a11cc32ef6a59583b03b194e8d4725dfb", null ],
      [ "_compileTargetOperations", "class_ogre_1_1_compositor_instance.html#ab021ecbc3214d82a8ce2702f95e21986", null ],
      [ "_compileOutputOperation", "class_ogre_1_1_compositor_instance.html#a5e916aa434bd181800d745ecbaf7399b", null ],
      [ "getCompositor", "class_ogre_1_1_compositor_instance.html#a4f11f86cc3933ae6cdf2e3eb535dd16d", null ],
      [ "getTechnique", "class_ogre_1_1_compositor_instance.html#ac048d0722c2ce2810a6a2803e18930f9", null ],
      [ "setTechnique", "class_ogre_1_1_compositor_instance.html#a4ccc07c70a060db2f4ba2e5ebaf6e7f2", null ],
      [ "setScheme", "class_ogre_1_1_compositor_instance.html#a0f111f02ceebc1a2589fc07663dbe2ee", null ],
      [ "getScheme", "class_ogre_1_1_compositor_instance.html#aec0619394a94b05cbb9455ae4eb3157e", null ],
      [ "notifyResized", "class_ogre_1_1_compositor_instance.html#ad3fc32b15a30103aa2555758f790ac10", null ],
      [ "getChain", "class_ogre_1_1_compositor_instance.html#a4ddf8670a1026cd4e868b3e8a92b1c73", null ],
      [ "addListener", "class_ogre_1_1_compositor_instance.html#ad2dcb9ae6aa4e0dfc0843a4cab32f800", null ],
      [ "removeListener", "class_ogre_1_1_compositor_instance.html#af0e83615e807bcadef8d6024cda6ec7d", null ],
      [ "_fireNotifyMaterialSetup", "class_ogre_1_1_compositor_instance.html#a62c2d7f611437483668ccf250a4841b9", null ],
      [ "_fireNotifyMaterialRender", "class_ogre_1_1_compositor_instance.html#a356f66a6f94b53ebbe1fee71f219bfaf", null ],
      [ "_fireNotifyResourcesCreated", "class_ogre_1_1_compositor_instance.html#aee02ac503204d70ebb46c41e83b46e2d", null ],
      [ "_fireNotifyResourcesReleased", "class_ogre_1_1_compositor_instance.html#a4e8600e4aaf6b43567a4590d2132bf5d", null ],
      [ "CompositorChain", "class_ogre_1_1_compositor_instance.html#a37ae5ce58afd2f0684c967bb1e780f58", null ],
      [ "Compositor", "class_ogre_1_1_compositor_instance.html#a1772c8d09c3483f000e7fce528d44d17", null ]
    ] ],
    [ "Ogre::CompositorLogic", "class_ogre_1_1_compositor_logic.html", [
      [ "~CompositorLogic", "class_ogre_1_1_compositor_logic.html#adb5d5a92b735eec00a40426bd91c4e8b", null ],
      [ "compositorInstanceCreated", "class_ogre_1_1_compositor_logic.html#abaec84ca5c9b9c4f0f200596e0c90f05", null ],
      [ "compositorInstanceDestroyed", "class_ogre_1_1_compositor_logic.html#a9e2e7c3c5cf9818540ccfef36844d6ed", null ]
    ] ],
    [ "Ogre::CompositorManager", "class_ogre_1_1_compositor_manager.html", [
      [ "UniqueTextureSet", "class_ogre_1_1_compositor_manager.html#a412c661642f90327cc59eea475194b81", null ],
      [ "CompositorManager", "class_ogre_1_1_compositor_manager.html#aeb2dde02f0631082a73fafcff189f3d7", null ],
      [ "~CompositorManager", "class_ogre_1_1_compositor_manager.html#ac758255395ad3b00bea001aa0aaf88d6", null ],
      [ "create", "class_ogre_1_1_compositor_manager.html#aa8e6e8df0d1413256a0b961fe929eab7", null ],
      [ "getByName", "class_ogre_1_1_compositor_manager.html#a774da533de0e9dc7263551a37136a2c6", null ],
      [ "getCompositorChain", "class_ogre_1_1_compositor_manager.html#aa9897c6f8287aee48aa96e7ffcf29de5", null ],
      [ "hasCompositorChain", "class_ogre_1_1_compositor_manager.html#aa4fc21a9b8393b670c732dfbfa0e7577", null ],
      [ "removeCompositorChain", "class_ogre_1_1_compositor_manager.html#a5d3c650de250cd3cb66484730fd4f95a", null ],
      [ "addCompositor", "class_ogre_1_1_compositor_manager.html#ab3f3a6e9ea6abe6edbb428613a8b866a", null ],
      [ "removeCompositor", "class_ogre_1_1_compositor_manager.html#a95a06faa7dac1be13f90b723ed8fa625", null ],
      [ "setCompositorEnabled", "class_ogre_1_1_compositor_manager.html#a40c9604cabf06d767110f4c2d73cf65d", null ],
      [ "_getTexturedRectangle2D", "class_ogre_1_1_compositor_manager.html#abc22280b859b4f57bb71a63374c36032", null ],
      [ "removeAll", "class_ogre_1_1_compositor_manager.html#a40feb1956c7edd68fd65835a44db84b0", null ],
      [ "_reconstructAllCompositorResources", "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb", null ],
      [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#a13a596ef6964a68dc25e9858b2201d26", null ],
      [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f", null ],
      [ "freePooledTextures", "class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf", null ],
      [ "registerCompositorLogic", "class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c", null ],
      [ "unregisterCompositorLogic", "class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c", null ],
      [ "getCompositorLogic", "class_ogre_1_1_compositor_manager.html#a19e9fac87ffda184125510157b6d48ff", null ],
      [ "hasCompositorLogic", "class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788", null ],
      [ "registerCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9", null ],
      [ "unregisterCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04", null ],
      [ "getCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#a31073e01284c78ef183f8eba087aa9c1", null ],
      [ "hasCustomCompositionPass", "class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f", null ],
      [ "_relocateChain", "class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499", null ],
      [ "getSingleton", "class_ogre_1_1_compositor_manager.html#a14161d8b081fa94f9caae3a0473d08db", null ],
      [ "getSingletonPtr", "class_ogre_1_1_compositor_manager.html#a58f71f164aff7d56b1f2c563522b651a", null ]
    ] ],
    [ "Ogre::CustomCompositionPass", "class_ogre_1_1_custom_composition_pass.html", [
      [ "createOperation", "class_ogre_1_1_custom_composition_pass.html#a4f04b76126f4b667f4d4e62de1087044", null ]
    ] ],
    [ "Ogre::Particle", "class_ogre_1_1_particle.html", [
      [ "ParticleType", "class_ogre_1_1_particle.html#a64379cf6d35750c81e72317099cc27c0", [
        [ "Visual", "class_ogre_1_1_particle.html#a64379cf6d35750c81e72317099cc27c0af72cab2ce3d47d8aa4ec32797372bd81", null ],
        [ "Emitter", "class_ogre_1_1_particle.html#a64379cf6d35750c81e72317099cc27c0a42e46625a50eb279c03f665fa715d749", null ]
      ] ],
      [ "Particle", "class_ogre_1_1_particle.html#ac8af4974850cd869b3f2331927dce745", null ],
      [ "setDimensions", "class_ogre_1_1_particle.html#a66be6ec3287fed530dd67c85b4d9989a", null ],
      [ "hasOwnDimensions", "class_ogre_1_1_particle.html#af46071e47818d84449ee0c8e73737fa5", null ],
      [ "getOwnWidth", "class_ogre_1_1_particle.html#a36c144112c584887884808cfc2995f00", null ],
      [ "getOwnHeight", "class_ogre_1_1_particle.html#a891cf38059d9bb69189164f875c33515", null ],
      [ "setRotation", "class_ogre_1_1_particle.html#abfea8fc856e37f26eb5901e930c7b21f", null ],
      [ "getRotation", "class_ogre_1_1_particle.html#aca4d3655f4358caff928d76501dc9240", null ],
      [ "mWidth", "class_ogre_1_1_particle.html#acf84de5823b44d661616c97ee58cb372", null ],
      [ "mHeight", "class_ogre_1_1_particle.html#a9d39195526e161031a9f57bbfebf2da0", null ],
      [ "mRotation", "class_ogre_1_1_particle.html#a32fb0fa2c3adb521e1f3728990472da3", null ],
      [ "mPosition", "class_ogre_1_1_particle.html#a73e6fde004e85abb95378d3d9ca0da0a", null ],
      [ "mDirection", "class_ogre_1_1_particle.html#acdbcf9aeb0a82d00deb6dd0e75207016", null ],
      [ "mColour", "class_ogre_1_1_particle.html#a8a08fbdfdb1b3a0016b8b46dfaa4f5b3", null ],
      [ "mTimeToLive", "class_ogre_1_1_particle.html#a9f87c09d91da0de646d3e6e7d3718812", null ],
      [ "mTotalTimeToLive", "class_ogre_1_1_particle.html#a23d82c88a4efe9772861520f994dd9aa", null ],
      [ "mRotationSpeed", "class_ogre_1_1_particle.html#a5aef511f7bcbada271780f42ccfe717e", null ],
      [ "mParticleType", "class_ogre_1_1_particle.html#a931a2be6077dd30e596f19a5f5646ba5", null ],
      [ "mTexcoordIndex", "class_ogre_1_1_particle.html#a8a0444826539b2d22f70f6f31fff41d6", null ],
      [ "mRandomTexcoordOffset", "class_ogre_1_1_particle.html#a57996fdda0816205a318d0239707ab10", null ]
    ] ],
    [ "Ogre::ParticleAffector", "class_ogre_1_1_particle_affector.html", [
      [ "ParticleAffector", "class_ogre_1_1_particle_affector.html#aacc7b02cc126155d291dcd4ca092050e", null ],
      [ "~ParticleAffector", "class_ogre_1_1_particle_affector.html#a89f39b39422328cf8dd11c46eeccb9d0", null ],
      [ "_initParticle", "class_ogre_1_1_particle_affector.html#a5f401d9023e7bb484ff3ff49e70c9510", null ],
      [ "_affectParticles", "class_ogre_1_1_particle_affector.html#a61826c830fc3ef4f37410a656aae7a81", null ],
      [ "getType", "class_ogre_1_1_particle_affector.html#ad7938e99220cebbc414c73924eb46a74", null ]
    ] ],
    [ "Ogre::ParticleAffectorFactory", "class_ogre_1_1_particle_affector_factory.html", [
      [ "ParticleAffectorFactory", "class_ogre_1_1_particle_affector_factory.html#adefcc5659fbddb67e72ece498003500c", null ],
      [ "~ParticleAffectorFactory", "class_ogre_1_1_particle_affector_factory.html#ae030407c3bc3e4cdc997f58f000278ea", null ],
      [ "getName", "class_ogre_1_1_particle_affector_factory.html#a6315b2c094791ee6c6cdddc9c435cdec", null ],
      [ "createAffector", "class_ogre_1_1_particle_affector_factory.html#ae8ba50f72ca5e55f916a2f682066b8bc", null ],
      [ "destroyAffector", "class_ogre_1_1_particle_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd", null ]
    ] ],
    [ "Ogre::ParticleEmitter", "class_ogre_1_1_particle_emitter.html", [
      [ "ParticleEmitter", "class_ogre_1_1_particle_emitter.html#a7b4b98ece8e719524274bb35a0438299", null ],
      [ "~ParticleEmitter", "class_ogre_1_1_particle_emitter.html#a89159dbdcbc33a12b70a2712bd9b9da6", null ],
      [ "setPosition", "class_ogre_1_1_particle_emitter.html#aae174ed689d7748e3047bb4242440993", null ],
      [ "getPosition", "class_ogre_1_1_particle_emitter.html#a711850fb05107391b90c654a14b4e06d", null ],
      [ "setDirection", "class_ogre_1_1_particle_emitter.html#af41030fee74fd28fa295975da55404d4", null ],
      [ "getDirection", "class_ogre_1_1_particle_emitter.html#aac8039cf60bcb0fe8a0ca19d149948d3", null ],
      [ "setUp", "class_ogre_1_1_particle_emitter.html#a595cb72cb60c6566bee7204ef7d92ebd", null ],
      [ "getUp", "class_ogre_1_1_particle_emitter.html#a8696cf1639788270655467e52f24a893", null ],
      [ "setDirPositionReference", "class_ogre_1_1_particle_emitter.html#a73fc7ce8c6dc5bba68d5da1cca779c33", null ],
      [ "getDirPositionReference", "class_ogre_1_1_particle_emitter.html#a62b8c0ef6aa5cf9ed3114cf03e3a8f1a", null ],
      [ "getDirPositionReferenceEnabled", "class_ogre_1_1_particle_emitter.html#a334b3e2619d23844739a29bcad603e00", null ],
      [ "setAngle", "class_ogre_1_1_particle_emitter.html#aeb086f851624a470e1b5592b81418d39", null ],
      [ "getAngle", "class_ogre_1_1_particle_emitter.html#a7eb6636a82ef1293d4688a6f83fc2abc", null ],
      [ "setParticleVelocity", "class_ogre_1_1_particle_emitter.html#a659edec094aae09a7f1325e7e8fbc29a", null ],
      [ "setParticleVelocity", "class_ogre_1_1_particle_emitter.html#a8d8c2e2e39187abc715d911cfa802780", null ],
      [ "setMinParticleVelocity", "class_ogre_1_1_particle_emitter.html#a74daf160185c31ecee5481b50f976a1c", null ],
      [ "setMaxParticleVelocity", "class_ogre_1_1_particle_emitter.html#ae71153b3e6cdfcfeb3b49388f603b13b", null ],
      [ "getParticleVelocity", "class_ogre_1_1_particle_emitter.html#ab39d2d327c694ef553fc3159b680d1db", null ],
      [ "getMinParticleVelocity", "class_ogre_1_1_particle_emitter.html#ab477389178da76c28a12e07d1191bef4", null ],
      [ "getMaxParticleVelocity", "class_ogre_1_1_particle_emitter.html#a98d3f921cd9061414149636172557d71", null ],
      [ "setEmissionRate", "class_ogre_1_1_particle_emitter.html#acb690da52c45571e198e39857b6a6d89", null ],
      [ "getEmissionRate", "class_ogre_1_1_particle_emitter.html#a5b7e2e8dd8e695736a1038588c382fbe", null ],
      [ "setTimeToLive", "class_ogre_1_1_particle_emitter.html#aa4cc84bb842666d1a69d25375dac5d12", null ],
      [ "setTimeToLive", "class_ogre_1_1_particle_emitter.html#a0cdad11e98fe6af5c36ca88b83e439ac", null ],
      [ "setMinTimeToLive", "class_ogre_1_1_particle_emitter.html#a7151224f33967bb60d9bdf631cc432b9", null ],
      [ "setMaxTimeToLive", "class_ogre_1_1_particle_emitter.html#abff726acd08f87c5be8a77c2e7d0b9eb", null ],
      [ "getTimeToLive", "class_ogre_1_1_particle_emitter.html#a4e0b837e02c70c0cfc880f83ce6b6739", null ],
      [ "getMinTimeToLive", "class_ogre_1_1_particle_emitter.html#a6607b5a35ab594e8e5e01df766cd5462", null ],
      [ "getMaxTimeToLive", "class_ogre_1_1_particle_emitter.html#a23a30a598c10f44f59ad4cfd78bf2a10", null ],
      [ "setColour", "class_ogre_1_1_particle_emitter.html#a857218f119755b72b9d3afbc1d896446", null ],
      [ "setColour", "class_ogre_1_1_particle_emitter.html#a7f442353f518bf6caae127dac6d0b6ee", null ],
      [ "setColourRangeStart", "class_ogre_1_1_particle_emitter.html#a1c642db8ce58df3c61f431ebc9066277", null ],
      [ "setColourRangeEnd", "class_ogre_1_1_particle_emitter.html#a674566db12d25f32513a382a4118b5da", null ],
      [ "getColour", "class_ogre_1_1_particle_emitter.html#a006cd1c3c866b13a1750615a8ab9615b", null ],
      [ "getColourRangeStart", "class_ogre_1_1_particle_emitter.html#a328b02bfeed236500bd78cac8a6c8f46", null ],
      [ "getColourRangeEnd", "class_ogre_1_1_particle_emitter.html#ab7c3652defce597f609970151e521db4", null ],
      [ "_getEmissionCount", "class_ogre_1_1_particle_emitter.html#abbe8790383211d809e53c6fdfd9f0dcc", null ],
      [ "_initParticle", "class_ogre_1_1_particle_emitter.html#a3a8cec931c55752b3995cd631d40acd5", null ],
      [ "getType", "class_ogre_1_1_particle_emitter.html#a826773806a1fc8b1e6731421dd513209", null ],
      [ "setEnabled", "class_ogre_1_1_particle_emitter.html#a9d26a5cb04855bc93abe837dc7cb83ac", null ],
      [ "getEnabled", "class_ogre_1_1_particle_emitter.html#a96b7ceb94e86301975d9f2b47baee906", null ],
      [ "setStartTime", "class_ogre_1_1_particle_emitter.html#a8f9062c067ecb49776d4ce73cf41990d", null ],
      [ "getStartTime", "class_ogre_1_1_particle_emitter.html#a1be2d46c4f3a8bd1d4118d347397e245", null ],
      [ "setDuration", "class_ogre_1_1_particle_emitter.html#a7e54feab62fa032b0190f3817d9e3d7f", null ],
      [ "getDuration", "class_ogre_1_1_particle_emitter.html#a1e9a8af81722473eb516e36a27e885bd", null ],
      [ "setDuration", "class_ogre_1_1_particle_emitter.html#a2ed1a99178ad112142f9ff9ac95c553e", null ],
      [ "setMinDuration", "class_ogre_1_1_particle_emitter.html#a79a2560fdff854fce4e0daf7ebc91291", null ],
      [ "setMaxDuration", "class_ogre_1_1_particle_emitter.html#a9194f48e306289c7f3c7f77374febb01", null ],
      [ "getMinDuration", "class_ogre_1_1_particle_emitter.html#a777c4c5c065aae3d07637819300b15b5", null ],
      [ "getMaxDuration", "class_ogre_1_1_particle_emitter.html#a51159bb05720260843eb80fde34261fd", null ],
      [ "setRepeatDelay", "class_ogre_1_1_particle_emitter.html#a95517da295f74f765f031f63b4964fdf", null ],
      [ "getRepeatDelay", "class_ogre_1_1_particle_emitter.html#a27abb24bce18934c89568cb3e10dd08f", null ],
      [ "setRepeatDelay", "class_ogre_1_1_particle_emitter.html#a4a7903addb8535a17cf0d79cb43ce7dd", null ],
      [ "setMinRepeatDelay", "class_ogre_1_1_particle_emitter.html#aef756f0d236964369f790e8f4004993f", null ],
      [ "setMaxRepeatDelay", "class_ogre_1_1_particle_emitter.html#a2644282dc91a1ad0525bebd46a47f519", null ],
      [ "getMinRepeatDelay", "class_ogre_1_1_particle_emitter.html#a2fc108cba4892f8ae091ffd70a65a150", null ],
      [ "getMaxRepeatDelay", "class_ogre_1_1_particle_emitter.html#ae4ef39376340b5fc531e5e807e0e0e52", null ],
      [ "getName", "class_ogre_1_1_particle_emitter.html#af6d31b59feeae53d39efeeb991bb7404", null ],
      [ "setName", "class_ogre_1_1_particle_emitter.html#aa9d9846fd83ec7e272d3e5b663270800", null ],
      [ "getEmittedEmitter", "class_ogre_1_1_particle_emitter.html#af4303578f534f6347525ca691678de74", null ],
      [ "setEmittedEmitter", "class_ogre_1_1_particle_emitter.html#af05abefb4cf775522fc3cc8bf1cd57f9", null ],
      [ "isEmitted", "class_ogre_1_1_particle_emitter.html#a64d38a64642017c5ca73213b129aa8d8", null ],
      [ "setEmitted", "class_ogre_1_1_particle_emitter.html#a18544aba1642ac02cd2d50847a3f35b9", null ]
    ] ],
    [ "Ogre::ParticleEmitterFactory", "class_ogre_1_1_particle_emitter_factory.html", [
      [ "ParticleEmitterFactory", "class_ogre_1_1_particle_emitter_factory.html#ae7d84a60ac62a0ee941b690cb6c13ea1", null ],
      [ "~ParticleEmitterFactory", "class_ogre_1_1_particle_emitter_factory.html#ae60c102ff4c406309b4fd0b03af61f48", null ],
      [ "getName", "class_ogre_1_1_particle_emitter_factory.html#a81999da1779cbe5e0ff478f97d021fe2", null ],
      [ "createEmitter", "class_ogre_1_1_particle_emitter_factory.html#a33e2ef547be210dcf7796f429f41e63d", null ],
      [ "destroyEmitter", "class_ogre_1_1_particle_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462", null ]
    ] ],
    [ "Ogre::ParticleSystem", "class_ogre_1_1_particle_system.html", [
      [ "ParticleSystem", "class_ogre_1_1_particle_system.html#a81ed233c0233486b27aad24533060cc5", null ],
      [ "ParticleSystem", "class_ogre_1_1_particle_system.html#a81490172c81d1589027271694400b127", null ],
      [ "~ParticleSystem", "class_ogre_1_1_particle_system.html#a13ea0ada53e83ede5f78893f29bd8c45", null ],
      [ "setRenderer", "class_ogre_1_1_particle_system.html#a3aa26ab67c0ef0c38512f22f3a9c089f", null ],
      [ "getRenderer", "class_ogre_1_1_particle_system.html#a26710fc7606d9638962a41a8eb8ed5c1", null ],
      [ "getRendererName", "class_ogre_1_1_particle_system.html#a64ce63202976ae66e5ee70c36cdf26e3", null ],
      [ "addEmitter", "class_ogre_1_1_particle_system.html#a2e06014b1096db23e40efd13e45fed55", null ],
      [ "getEmitter", "class_ogre_1_1_particle_system.html#a40a902eedfd441e383d17992b648911d", null ],
      [ "getNumEmitters", "class_ogre_1_1_particle_system.html#a1d8478321672847799608aaf8c7e6652", null ],
      [ "removeEmitter", "class_ogre_1_1_particle_system.html#a57b8d8f483fe32b5a31d6ee8053c06fd", null ],
      [ "removeAllEmitters", "class_ogre_1_1_particle_system.html#a3519e95ea941d9ae121f8ed90c6d375a", null ],
      [ "removeEmitter", "class_ogre_1_1_particle_system.html#acd841865bf9b98e06c8520990115e6ec", null ],
      [ "addAffector", "class_ogre_1_1_particle_system.html#a3bbdf9ea3f28b0465e8e81e49d80ccf3", null ],
      [ "getAffector", "class_ogre_1_1_particle_system.html#afa0d5a4ff0888ba0817bd8122fe8a578", null ],
      [ "getNumAffectors", "class_ogre_1_1_particle_system.html#ad0a8b974b242fc5e34ac4afa6b83c754", null ],
      [ "removeAffector", "class_ogre_1_1_particle_system.html#a71e902e42b7df9ea3bd1e100e730d5b2", null ],
      [ "removeAllAffectors", "class_ogre_1_1_particle_system.html#a20fd87b1ce6f36400cf0769b1aab16d2", null ],
      [ "clear", "class_ogre_1_1_particle_system.html#a59c5bee716096d74a0698fbe57fd81b4", null ],
      [ "getNumParticles", "class_ogre_1_1_particle_system.html#a76823dcef82e7cd98a73a90780b316ac", null ],
      [ "createParticle", "class_ogre_1_1_particle_system.html#a7e96f6609b6b0c9a33614c09c04a5224", null ],
      [ "createEmitterParticle", "class_ogre_1_1_particle_system.html#a16c009cc3b5619f4e340d02bf8b08b58", null ],
      [ "getParticle", "class_ogre_1_1_particle_system.html#a0e16a8f7051771fdbf0a4eb93f96ee70", null ],
      [ "getParticleQuota", "class_ogre_1_1_particle_system.html#a1e6cc1a55cd052df5a4fc4fd3c073170", null ],
      [ "setParticleQuota", "class_ogre_1_1_particle_system.html#aa0e2cb40912f330b101b373c84ae1f83", null ],
      [ "getEmittedEmitterQuota", "class_ogre_1_1_particle_system.html#aa7d7f759e1425a5e3e68cbd0a0314921", null ],
      [ "setEmittedEmitterQuota", "class_ogre_1_1_particle_system.html#a6efbdc3b175a72c000c2c0bafd372ad2", null ],
      [ "operator=", "class_ogre_1_1_particle_system.html#a2ec6573a85f2d672f263e8ae3c24ee0d", null ],
      [ "_update", "class_ogre_1_1_particle_system.html#a3030f774cd9b9d6a1d822cb64403a756", null ],
      [ "_getActiveParticles", "class_ogre_1_1_particle_system.html#a3c2ae89e517f936946f131ad2e6facf6", null ],
      [ "setMaterialName", "class_ogre_1_1_particle_system.html#a4495534dfee31210a3ab22336d8f881e", null ],
      [ "getMaterialName", "class_ogre_1_1_particle_system.html#a6e202c3091bc612b5ca594c3871d2462", null ],
      [ "_notifyCurrentCamera", "class_ogre_1_1_particle_system.html#a6ad3b2684589bc934b63255e670f0cfb", null ],
      [ "_notifyAttached", "class_ogre_1_1_particle_system.html#ab6274ce63bb40584350d07a09ca180b6", null ],
      [ "getBoundingBox", "class_ogre_1_1_particle_system.html#aff68906a85997628c65484932e217bc1", null ],
      [ "getBoundingRadius", "class_ogre_1_1_particle_system.html#abfff892995a9e9dbc787a762e770d934", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_particle_system.html#a5c4edaeee40c622e441b5cf58975d977", null ],
      [ "visitRenderables", "class_ogre_1_1_particle_system.html#a9d62ecb7060588484a55f3c1fd8d7151", null ],
      [ "fastForward", "class_ogre_1_1_particle_system.html#aa027a959141f5ba4c5f756fc24cf8352", null ],
      [ "setSpeedFactor", "class_ogre_1_1_particle_system.html#afd8ec707603e16d1b0eec2e734486947", null ],
      [ "getSpeedFactor", "class_ogre_1_1_particle_system.html#a30da9fbfd36fabe5b73ed13ec621cbce", null ],
      [ "setIterationInterval", "class_ogre_1_1_particle_system.html#af0edf2f193b03413a0980d9f106462de", null ],
      [ "getIterationInterval", "class_ogre_1_1_particle_system.html#a146c219eb4aef13582b40f9aba355763", null ],
      [ "setDefaultIterationInterval", "class_ogre_1_1_particle_system.html#acf264915a826cb9a9ad5c6ce14918ea9", null ],
      [ "getDefaultIterationInterval", "class_ogre_1_1_particle_system.html#afb67c669b0ff93223c49911735fe9cd4", null ],
      [ "setNonVisibleUpdateTimeout", "class_ogre_1_1_particle_system.html#acbba685176e0d844d8aa82472406595c", null ],
      [ "getNonVisibleUpdateTimeout", "class_ogre_1_1_particle_system.html#a32e013c53715759c78efd0a25182eefb", null ],
      [ "setDefaultNonVisibleUpdateTimeout", "class_ogre_1_1_particle_system.html#aeee3216615e86c4279b73cd48297e2ed", null ],
      [ "getDefaultNonVisibleUpdateTimeout", "class_ogre_1_1_particle_system.html#a946522b763de11b1876941ba83f9621c", null ],
      [ "getMovableType", "class_ogre_1_1_particle_system.html#a36c0f7af92119b560f1a514597388645", null ],
      [ "setDefaultDimensions", "class_ogre_1_1_particle_system.html#a856634cd1ca9fe95928559effba4d21a", null ],
      [ "setDefaultWidth", "class_ogre_1_1_particle_system.html#a9c500036979d745b11448eeb6e730335", null ],
      [ "getDefaultWidth", "class_ogre_1_1_particle_system.html#afbb91aaac3a333892d2ad159bf0d333f", null ],
      [ "setDefaultHeight", "class_ogre_1_1_particle_system.html#a8d24a0601115d991c92a8c93c28e01a3", null ],
      [ "getDefaultHeight", "class_ogre_1_1_particle_system.html#a37b6ca445fa07c8702dad9ced80ed26d", null ],
      [ "getCullIndividually", "class_ogre_1_1_particle_system.html#a010bc8e15acd3b36e8c389a67d67e817", null ],
      [ "setCullIndividually", "class_ogre_1_1_particle_system.html#a3819fad31a2b507060becb0768b2992c", null ],
      [ "getResourceGroupName", "class_ogre_1_1_particle_system.html#ab831904aec45f33e2114625a792e5f9f", null ],
      [ "getOrigin", "class_ogre_1_1_particle_system.html#ad0641eee89f5f047121cfd261e82fff9", null ],
      [ "_notifyOrigin", "class_ogre_1_1_particle_system.html#aae2a5b0da71f9b6f9885a7b32ac4753d", null ],
      [ "setRenderQueueGroup", "class_ogre_1_1_particle_system.html#a22cc682d26dc6a3502632829323464d8", null ],
      [ "setRenderQueueGroupAndPriority", "class_ogre_1_1_particle_system.html#ac776022f1f5cbe53744720d4de8398b8", null ],
      [ "setSortingEnabled", "class_ogre_1_1_particle_system.html#a976394bc64e81a01338e37c669c8614b", null ],
      [ "getSortingEnabled", "class_ogre_1_1_particle_system.html#ac3cdc48fa1fedce3781b9b528e655e79", null ],
      [ "setBounds", "class_ogre_1_1_particle_system.html#a6fd1b49ea04e24dd2b6ff46ecd8cc5c3", null ],
      [ "setBoundsAutoUpdated", "class_ogre_1_1_particle_system.html#a47e0f94b4d6e8a411f6b2f6b7671218b", null ],
      [ "setKeepParticlesInLocalSpace", "class_ogre_1_1_particle_system.html#a124ab1e0b05d9d035536379028abbf08", null ],
      [ "getKeepParticlesInLocalSpace", "class_ogre_1_1_particle_system.html#aeaee08ea585af412a0a5a4b253a1e847", null ],
      [ "_updateBounds", "class_ogre_1_1_particle_system.html#abf119c3f1428b81d16800115d33a2610", null ],
      [ "setEmitting", "class_ogre_1_1_particle_system.html#ada8ee7ffd336cb26d5405a15d781fc36", null ],
      [ "getEmitting", "class_ogre_1_1_particle_system.html#a6ac1533704c8271c0f82a66382f9a654", null ],
      [ "getTypeFlags", "class_ogre_1_1_particle_system.html#adab70d1fed0076649ef2e3a53900608f", null ]
    ] ],
    [ "Ogre::ParticleSystemManager", "class_ogre_1_1_particle_system_manager.html", [
      [ "ParticleTemplateMap", "class_ogre_1_1_particle_system_manager.html#a0d577516475b87958099c37416c87d5c", null ],
      [ "ParticleAffectorFactoryMap", "class_ogre_1_1_particle_system_manager.html#a34238313f2463dd05a67442732f1b80b", null ],
      [ "ParticleEmitterFactoryMap", "class_ogre_1_1_particle_system_manager.html#ae47b0ad1c92b7688fdd82b01faadb896", null ],
      [ "ParticleSystemRendererFactoryMap", "class_ogre_1_1_particle_system_manager.html#a70adc307673f285616c2676d5e73286e", null ],
      [ "ParticleAffectorFactoryIterator", "class_ogre_1_1_particle_system_manager.html#acbec6e41cd83bce4c74ccda2910a9f9d", null ],
      [ "ParticleEmitterFactoryIterator", "class_ogre_1_1_particle_system_manager.html#ae09f451e66186b1151d8938408bf643a", null ],
      [ "ParticleRendererFactoryIterator", "class_ogre_1_1_particle_system_manager.html#ac35fdf5ee3749263881983cec21abd79", null ],
      [ "ParticleSystemTemplateIterator", "class_ogre_1_1_particle_system_manager.html#a6af21cf51363b600f9798487f6465518", null ],
      [ "ParticleSystemManager", "class_ogre_1_1_particle_system_manager.html#a56d3c0d02fed62ca777ced0646fe95ad", null ],
      [ "~ParticleSystemManager", "class_ogre_1_1_particle_system_manager.html#aaae43e60e255abb2409146386bb657b8", null ],
      [ "addEmitterFactory", "class_ogre_1_1_particle_system_manager.html#a490aff428f1680806e1928782e2c12fb", null ],
      [ "addAffectorFactory", "class_ogre_1_1_particle_system_manager.html#a602a4d23eb415b291f66f83423891911", null ],
      [ "addRendererFactory", "class_ogre_1_1_particle_system_manager.html#a448961936e5ca24ced6f69146f8be8cd", null ],
      [ "addTemplate", "class_ogre_1_1_particle_system_manager.html#ab9bc0806919eee426e09ec31c2c4d59a", null ],
      [ "removeTemplate", "class_ogre_1_1_particle_system_manager.html#a5a28bfef2b541e7d98d89c753ac4edde", null ],
      [ "removeAllTemplates", "class_ogre_1_1_particle_system_manager.html#a7ae8a858947a4ad156f3ededf641be61", null ],
      [ "removeTemplatesByResourceGroup", "class_ogre_1_1_particle_system_manager.html#a7647aebf518f60116028f5b6c76305a3", null ],
      [ "createTemplate", "class_ogre_1_1_particle_system_manager.html#a95771ff3eb0b9a9751e1a8864cfeed13", null ],
      [ "getTemplate", "class_ogre_1_1_particle_system_manager.html#a5dd540ada81625567d0e9d2a144c8071", null ],
      [ "_createEmitter", "class_ogre_1_1_particle_system_manager.html#a3f0c9b81c57cc3e1d8c4043865877bc6", null ],
      [ "_destroyEmitter", "class_ogre_1_1_particle_system_manager.html#a10f79cb98ca93df0104fd04230d09f0d", null ],
      [ "_createAffector", "class_ogre_1_1_particle_system_manager.html#aea44d7f4c398b3ee3fc49ccc6c4498e1", null ],
      [ "_destroyAffector", "class_ogre_1_1_particle_system_manager.html#a2f5fec80e6489a218c8d3407a2d5a6e9", null ],
      [ "_createRenderer", "class_ogre_1_1_particle_system_manager.html#ab7466d1d31bbd3806fdf6144d8707cad", null ],
      [ "_destroyRenderer", "class_ogre_1_1_particle_system_manager.html#ac1dd25a362850584a0dc7a2227b4f840", null ],
      [ "_initialise", "class_ogre_1_1_particle_system_manager.html#add15cf5f54484482a1cd37a8d3300c6b", null ],
      [ "getAffectorFactoryIterator", "class_ogre_1_1_particle_system_manager.html#a0a7d5c8ee754b7559e9701df048f3777", null ],
      [ "getEmitterFactoryIterator", "class_ogre_1_1_particle_system_manager.html#a09b60382058f433aa0bfa709d876487e", null ],
      [ "getRendererFactoryIterator", "class_ogre_1_1_particle_system_manager.html#a641d951f1c3f9693be0ca7bdedcf80fc", null ],
      [ "getTemplateIterator", "class_ogre_1_1_particle_system_manager.html#a1b4d71c58e8d0e738a252e73638a13fd", null ],
      [ "_getFactory", "class_ogre_1_1_particle_system_manager.html#a8ca451f2d327af3047090c244d04d3b8", null ],
      [ "getSingleton", "class_ogre_1_1_particle_system_manager.html#a7cd19584bb1dcf9c08f021065fca9d0f", null ],
      [ "getSingletonPtr", "class_ogre_1_1_particle_system_manager.html#a8f422da63d9c8f915db07c14f53e3e3d", null ],
      [ "ParticleSystemFactory", "class_ogre_1_1_particle_system_manager.html#ab020c8dc08fa7956c9b1fb400a99a027", null ]
    ] ],
    [ "Ogre::ParticleSystemRenderer", "class_ogre_1_1_particle_system_renderer.html", [
      [ "ParticleSystemRenderer", "class_ogre_1_1_particle_system_renderer.html#a18d83b417a606c9d40f87fffe003ef2a", null ],
      [ "~ParticleSystemRenderer", "class_ogre_1_1_particle_system_renderer.html#acedd9af6338bc40603a571333be5f5f9", null ],
      [ "getType", "class_ogre_1_1_particle_system_renderer.html#ac9b2645b2dbf9ce84c61ffdb86223fc6", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_particle_system_renderer.html#a093cbb957dfff77988f0345f1b832e89", null ],
      [ "_setMaterial", "class_ogre_1_1_particle_system_renderer.html#acef7b4bfb05626da291588d55f768cc9", null ],
      [ "_notifyCurrentCamera", "class_ogre_1_1_particle_system_renderer.html#a36ec310fb97f85ed7ca1d5176024bfcc", null ],
      [ "_notifyAttached", "class_ogre_1_1_particle_system_renderer.html#aa77068e24ca3ff941e5608f841eee433", null ],
      [ "_notifyParticleQuota", "class_ogre_1_1_particle_system_renderer.html#a018bd2ae834c1aba8b9fa79116e67c44", null ],
      [ "_notifyDefaultDimensions", "class_ogre_1_1_particle_system_renderer.html#a2e0b651fd9d845b9bc70e9aaf64e5915", null ],
      [ "_notifyParticleEmitted", "class_ogre_1_1_particle_system_renderer.html#aec55835fcde21e77487cfbb20f439944", null ],
      [ "_notifyParticleExpired", "class_ogre_1_1_particle_system_renderer.html#a64ca1a8e9f77c857d2ffdab29fbdd598", null ],
      [ "_notifyParticleMoved", "class_ogre_1_1_particle_system_renderer.html#ab691a5f1b02af4fabac13944aabe9feb", null ],
      [ "_notifyParticleCleared", "class_ogre_1_1_particle_system_renderer.html#a20d2299fe552365030df11eccf722c5e", null ],
      [ "_createVisualData", "class_ogre_1_1_particle_system_renderer.html#a46d71e932178a51ecf76058a58971561", null ],
      [ "_destroyVisualData", "class_ogre_1_1_particle_system_renderer.html#a6bf33e96c44ee9606ecc9684f1f68792", null ],
      [ "setRenderQueueGroup", "class_ogre_1_1_particle_system_renderer.html#ac586ecbee5141ce024ff371de137a952", null ],
      [ "setRenderQueueGroupAndPriority", "class_ogre_1_1_particle_system_renderer.html#ad17f9c220432043c233987944487ca2c", null ],
      [ "setKeepParticlesInLocalSpace", "class_ogre_1_1_particle_system_renderer.html#a9d51542da9e252f542e9ba7d89f575c1", null ],
      [ "_getSortMode", "class_ogre_1_1_particle_system_renderer.html#a2b90d2d5d6b6a46e59e409c54d7dc198", null ],
      [ "visitRenderables", "class_ogre_1_1_particle_system_renderer.html#afe69c31bb92ee5c1e97bcb5ced09f862", null ],
      [ "_notifyBoundingBox", "class_ogre_1_1_particle_system_renderer.html#a43012edd7cdea95752c81e66beb3dceb", null ],
      [ "_notifyCastShadows", "class_ogre_1_1_particle_system_renderer.html#afddb13354b324ff984998cc507b8cd0f", null ]
    ] ],
    [ "Ogre::RibbonTrail", "class_ogre_1_1_ribbon_trail.html", [
      [ "NodeList", "class_ogre_1_1_ribbon_trail.html#acc8002296a48321ac318f99a77c82ef4", null ],
      [ "NodeIterator", "class_ogre_1_1_ribbon_trail.html#aa87dbc42370145c7829bce54b0919e03", null ],
      [ "RibbonTrail", "class_ogre_1_1_ribbon_trail.html#a7ef20f333691fe7fb5cce5bb1d7c8012", null ],
      [ "~RibbonTrail", "class_ogre_1_1_ribbon_trail.html#a8a166f5eebda9774c286a90963eb2a46", null ],
      [ "addNode", "class_ogre_1_1_ribbon_trail.html#abeddfc60ef032d61276e5b694cb883df", null ],
      [ "removeNode", "class_ogre_1_1_ribbon_trail.html#a7871d546a48c127e6068ef7f408842d5", null ],
      [ "getNodeIterator", "class_ogre_1_1_ribbon_trail.html#aa51b1f3a6fee616dfecb05965db78fe4", null ],
      [ "getChainIndexForNode", "class_ogre_1_1_ribbon_trail.html#a9f1fb9b8c18a39375d65cac3441a2fb4", null ],
      [ "setTrailLength", "class_ogre_1_1_ribbon_trail.html#ae7deac4e95e9ae76650d9576f363fa4a", null ],
      [ "getTrailLength", "class_ogre_1_1_ribbon_trail.html#afcb2546e8ec7769f7111f03a6a2cc6d4", null ],
      [ "setMaxChainElements", "class_ogre_1_1_ribbon_trail.html#acc5d84beeb6b521dad7407d8aa11777f", null ],
      [ "setNumberOfChains", "class_ogre_1_1_ribbon_trail.html#ac710cc931767fc3b2018b4fac708678b", null ],
      [ "clearChain", "class_ogre_1_1_ribbon_trail.html#a4b9562a9764b7ce5d4db6fc9c59deff8", null ],
      [ "setInitialColour", "class_ogre_1_1_ribbon_trail.html#ac98c4fa0f7c412751c4352eb8d0e39a1", null ],
      [ "setInitialColour", "class_ogre_1_1_ribbon_trail.html#ad554af1a54fb650197947467b2d88839", null ],
      [ "getInitialColour", "class_ogre_1_1_ribbon_trail.html#a58422667fcb7d29dfaca1f0a851ad628", null ],
      [ "setColourChange", "class_ogre_1_1_ribbon_trail.html#aa64743cce7cede32aadf23a0d6298958", null ],
      [ "setInitialWidth", "class_ogre_1_1_ribbon_trail.html#a9e71b08aa64add5e1262e2de15b0becc", null ],
      [ "getInitialWidth", "class_ogre_1_1_ribbon_trail.html#ab625b0ac07ebb001cf22e089e4ef05ec", null ],
      [ "setWidthChange", "class_ogre_1_1_ribbon_trail.html#a7fd33999495bf1c773331a5db80b0cac", null ],
      [ "getWidthChange", "class_ogre_1_1_ribbon_trail.html#a9ef35b8521c1007645abc1eaa3098832", null ],
      [ "setColourChange", "class_ogre_1_1_ribbon_trail.html#abd091e77be6e22fdd018aada0961f5c8", null ],
      [ "getColourChange", "class_ogre_1_1_ribbon_trail.html#a443d866366335cbf106fe4cc31c80c86", null ],
      [ "nodeUpdated", "class_ogre_1_1_ribbon_trail.html#a16c72a3ce2081cbbf3cc01bf907bfa67", null ],
      [ "nodeDestroyed", "class_ogre_1_1_ribbon_trail.html#aa7a7e14c85c2875f9c70982cdb5aab6b", null ],
      [ "_timeUpdate", "class_ogre_1_1_ribbon_trail.html#ab67b6492b1c8e5687d9623f1518e86ac", null ],
      [ "getMovableType", "class_ogre_1_1_ribbon_trail.html#a8ac5a54349431efa4c210b7a74f60d91", null ]
    ] ],
    [ "Ogre::BillboardOrigin", "group___effects.html#ga37abc46b1f74f855e13334aa44f4ec5e", [
      [ "Ogre::BBO_TOP_LEFT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea2f0d9a0c7a6232a62819ba5f8088ce41", null ],
      [ "Ogre::BBO_TOP_CENTER", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5eaec907934218991032b9b5f34a2d0d612", null ],
      [ "Ogre::BBO_TOP_RIGHT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea183e54039d91c27835e5f7a066f8e485", null ],
      [ "Ogre::BBO_CENTER_LEFT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea306c93ed76b358c9d6aef5b6ff413857", null ],
      [ "Ogre::BBO_CENTER", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5eab17acd1195e321856b4e5a91ccb300a4", null ],
      [ "Ogre::BBO_CENTER_RIGHT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea4456ff76b26ecc97f3c34c2c709cf47b", null ],
      [ "Ogre::BBO_BOTTOM_LEFT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea6434f4b60d73ffb70c9ceefd1b5595dc", null ],
      [ "Ogre::BBO_BOTTOM_CENTER", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5ea928ae6264de474f12e6e3ca00419ae2b", null ],
      [ "Ogre::BBO_BOTTOM_RIGHT", "group___effects.html#gga37abc46b1f74f855e13334aa44f4ec5eab67c73db2cf842dee641805c415901cb", null ]
    ] ],
    [ "Ogre::BillboardRotationType", "group___effects.html#ga4f3a37a5b62f0a2ddda53f789e736cbd", [
      [ "Ogre::BBR_VERTEX", "group___effects.html#gga4f3a37a5b62f0a2ddda53f789e736cbda6a7f6b74eba56f5035dab96d94b07cad", null ],
      [ "Ogre::BBR_TEXCOORD", "group___effects.html#gga4f3a37a5b62f0a2ddda53f789e736cbdafc76d69a1ee25ad91871544eca2ca03f", null ]
    ] ],
    [ "Ogre::BillboardType", "group___effects.html#ga8a7bd8c019e0d8e7049e855847af2a1c", [
      [ "Ogre::BBT_POINT", "group___effects.html#gga8a7bd8c019e0d8e7049e855847af2a1caafd0ef3ee3353703249e160930424b7d", null ],
      [ "Ogre::BBT_ORIENTED_COMMON", "group___effects.html#gga8a7bd8c019e0d8e7049e855847af2a1cacfc7dcc9adc26c7b19c0a7047ee5ec1b", null ],
      [ "Ogre::BBT_ORIENTED_SELF", "group___effects.html#gga8a7bd8c019e0d8e7049e855847af2a1cabffcbe8d1e5e7d545d8f33762db75176", null ],
      [ "Ogre::BBT_PERPENDICULAR_COMMON", "group___effects.html#gga8a7bd8c019e0d8e7049e855847af2a1ca9f88ba12ab6dd77447b73a0272147a4f", null ],
      [ "Ogre::BBT_PERPENDICULAR_SELF", "group___effects.html#gga8a7bd8c019e0d8e7049e855847af2a1cab4c7cffc09bcc71b32cb6b4e5f758ee6", null ]
    ] ]
];